@@ -17,6 +17,7 @@ Archive Common
 #include "common/regExp.h"
 #include "common/wait.h"
 #include "config/config.h"
+#include "postgres/interface.h"
 #include "postgres/version.h"
 #include "storage/helper.h"
 #include "storage/helper.h"
@@ -34,10 +35,10 @@ STRING_EXTERN(WAL_TIMELINE_HISTORY_REGEXP_STR,                      WAL_TIMELINE
 Global error file constant
 ***********************************************************************************************************************************/
 #define STATUS_FILE_GLOBAL                                          "global"
-    STRING_STATIC(STATUS_FILE_GLOBAL_STR,                           STATUS_FILE_GLOBAL);
+STRING_STATIC(STATUS_FILE_GLOBAL_STR,                               STATUS_FILE_GLOBAL);
 
 #define STATUS_FILE_GLOBAL_ERROR                                    STATUS_FILE_GLOBAL STATUS_EXT_ERROR
-    STRING_STATIC(STATUS_FILE_GLOBAL_ERROR_STR,                         STATUS_FILE_GLOBAL_ERROR);
+STRING_STATIC(STATUS_FILE_GLOBAL_ERROR_STR,                         STATUS_FILE_GLOBAL_ERROR);
 
 /***********************************************************************************************************************************
 Get the correct spool queue based on the archive mode
@@ -49,12 +50,13 @@ archiveAsyncSpoolQueue(ArchiveMode archiveMode)
         FUNCTION_TEST_PARAM(STRING_ID, archiveMode);
     FUNCTION_TEST_END();
 
-    FUNCTION_TEST_RETURN((archiveMode == archiveModeGet ? STORAGE_SPOOL_ARCHIVE_IN_STR : STORAGE_SPOOL_ARCHIVE_OUT_STR));
+    FUNCTION_TEST_RETURN_CONST(
+        STRING, archiveMode == archiveModeGet ? STORAGE_SPOOL_ARCHIVE_IN_STR : STORAGE_SPOOL_ARCHIVE_OUT_STR);
 }
 
 /**********************************************************************************************************************************/
-void
-archiveAsyncErrorClear(ArchiveMode archiveMode, const String *archiveFile)
+FN_EXTERN void
+archiveAsyncErrorClear(const ArchiveMode archiveMode, const String *const archiveFile)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
         FUNCTION_LOG_PARAM(STRING_ID, archiveMode);
@@ -63,14 +65,18 @@ archiveAsyncErrorClear(ArchiveMode archiveMode, const String *archiveFile)
 
     ASSERT(archiveFile != NULL);
 
-    storageRemoveP(storageSpoolWrite(), strNewFmt(STORAGE_SPOOL_ARCHIVE_OUT "/%s" STATUS_EXT_ERROR, strZ(archiveFile)));
+    String *const errorFile = strNewFmt(STORAGE_SPOOL_ARCHIVE_OUT "/%s" STATUS_EXT_ERROR, strZ(archiveFile));
+
+    storageRemoveP(storageSpoolWrite(), errorFile);
     storageRemoveP(storageSpoolWrite(), STRDEF(STORAGE_SPOOL_ARCHIVE_OUT "/" STATUS_FILE_GLOBAL_ERROR));
 
+    strFree(errorFile);
+
     FUNCTION_LOG_RETURN_VOID();
 }
 
 /**********************************************************************************************************************************/
-bool
+FN_EXTERN bool
 archiveAsyncStatus(ArchiveMode archiveMode, const String *walSegment, bool throwOnError, bool warnOnOk)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
@@ -113,7 +119,7 @@ archiveAsyncStatus(ArchiveMode archiveMode, const String *walSegment, bool throw
         if (okFileExists || errorFileExists)
         {
             // Get the status file content
-            const String *statusFile = okFileExists ? okFile: errorFile;
+            const String *statusFile = okFileExists ? okFile : errorFile;
 
             String *content = strNewBuf(
                 storageGetP(storageNewReadP(storageSpool(), strNewFmt("%s/%s", strZ(spoolQueue), strZ(statusFile)))));
@@ -176,7 +182,7 @@ archiveAsyncStatus(ArchiveMode archiveMode, const String *walSegment, bool throw
 }
 
 /**********************************************************************************************************************************/
-void
+FN_EXTERN void
 archiveAsyncStatusErrorWrite(ArchiveMode archiveMode, const String *walSegment, int code, const String *message)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
@@ -205,7 +211,7 @@ archiveAsyncStatusErrorWrite(ArchiveMode archiveMode, const String *walSegment,
 }
 
 /**********************************************************************************************************************************/
-void
+FN_EXTERN void
 archiveAsyncStatusOkWrite(ArchiveMode archiveMode, const String *walSegment, const String *warning)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
@@ -230,7 +236,7 @@ archiveAsyncStatusOkWrite(ArchiveMode archiveMode, const String *walSegment, con
 }
 
 /**********************************************************************************************************************************/
-void
+FN_EXTERN void
 archiveAsyncExec(ArchiveMode archiveMode, const StringList *commandExec)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
@@ -257,9 +263,9 @@ archiveAsyncExec(ArchiveMode archiveMode, const StringList *commandExec)
         for (int fd = 3; fd < 1024; fd++)
             close(fd);
 
-        // Execute the binary.  This statement will not return if it is successful.
+        // Execute the binary. This statement will not return if it is successful.
         THROW_ON_SYS_ERROR_FMT(
-            execvp(strZ(strLstGet(commandExec, 0)), (char ** const)strLstPtr(commandExec)) == -1, ExecuteError,
+            execvp(strZ(strLstGet(commandExec, 0)), (char **const)strLstPtr(commandExec)) == -1, ExecuteError,
             "unable to execute asynchronous '%s'", archiveMode == archiveModeGet ? CFGCMD_ARCHIVE_GET : CFGCMD_ARCHIVE_PUSH);
     }
 
@@ -273,21 +279,21 @@ archiveAsyncExec(ArchiveMode archiveMode, const StringList *commandExec)
 
     THROW_ON_SYS_ERROR(waitpid(pid, &processStatus, 0) == -1, ExecuteError, "unable to wait for forked process");
 
-    // The first fork should exit with success.  If not, something went wrong during the second fork.
-    CHECK(WIFEXITED(processStatus) && WEXITSTATUS(processStatus) == 0);
+    // The first fork should exit with success. If not, something went wrong during the second fork.
+    CHECK(ExecuteError, WIFEXITED(processStatus) && WEXITSTATUS(processStatus) == 0, "error on first fork");
 
 #ifdef DEBUG_EXEC_TIME
-    // If the process does not exit immediately then something probably went wrong with the double fork.  It's possible that this
-    // test will fail on very slow systems so it may need to be tuned.  The idea is to make sure that the waitpid() above is not
+    // If the process does not exit immediately then something probably went wrong with the double fork. It's possible that this
+    // test will fail on very slow systems so it may need to be tuned. The idea is to make sure that the waitpid() above is not
     // waiting on the async process.
-    ASSERT(timeMSec() - timeBegin < 10);
+    CHECK(AssertError, timeMSec() - timeBegin < 10, "the process does not exit immediately");
 #endif
 
     FUNCTION_LOG_RETURN_VOID();
 }
 
 /**********************************************************************************************************************************/
-int
+FN_EXTERN int
 archiveIdComparator(const void *item1, const void *item2)
 {
     StringList *archiveSort1 = strLstNewSplitZ(*(String **)item1, "-");
@@ -295,11 +301,11 @@ archiveIdComparator(const void *item1, const void *item2)
     int int1 = atoi(strZ(strLstGet(archiveSort1, 1)));
     int int2 = atoi(strZ(strLstGet(archiveSort2, 1)));
 
-    return (int1 - int2);
+    return int1 - int2;
 }
 
 /**********************************************************************************************************************************/
-bool
+FN_EXTERN bool
 walIsPartial(const String *walSegment)
 {
     FUNCTION_LOG_BEGIN(logLevelTrace);
@@ -313,7 +319,7 @@ walIsPartial(const String *walSegment)
 }
 
 /**********************************************************************************************************************************/
-String *
+FN_EXTERN String *
 walPath(const String *walFile, const String *pgPath, const String *command)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
@@ -335,8 +341,8 @@ walPath(const String *walFile, const String *pgPath, const String *command)
             THROW_FMT(
                 OptionRequiredError,
                 "option '%s' must be specified when relative wal paths are used\n"
-                    "HINT: is %%f passed to %s instead of %%p?\n"
-                    "HINT: PostgreSQL may pass relative paths even with %%p depending on the environment.",
+                "HINT: is %%f passed to %s instead of %%p?\n"
+                "HINT: PostgreSQL may pass relative paths even with %%p depending on the environment.",
                 cfgOptionName(cfgOptPgPath), strZ(command));
         }
 
@@ -361,7 +367,7 @@ walPath(const String *walFile, const String *pgPath, const String *command)
                 THROW_FMT(
                     OptionInvalidValueError,
                     PG_NAME " working directory '%s' is not the same as option %s '%s'\n"
-                        "HINT: is the " PG_NAME " data_directory configured the same as the %s option?",
+                    "HINT: is the " PG_NAME " data_directory configured the same as the %s option?",
                     currentWorkDir, cfgOptionName(cfgOptPgPath), strZ(pgPath), cfgOptionName(cfgOptPgPath));
             }
         }
@@ -375,7 +381,7 @@ walPath(const String *walFile, const String *pgPath, const String *command)
 }
 
 /**********************************************************************************************************************************/
-bool
+FN_EXTERN bool
 walIsSegment(const String *walSegment)
 {
     FUNCTION_LOG_BEGIN(logLevelTrace);
@@ -400,7 +406,7 @@ walIsSegment(const String *walSegment)
 }
 
 /**********************************************************************************************************************************/
-String *
+FN_EXTERN String *
 walSegmentFind(const Storage *storage, const String *archiveId, const String *walSegment, TimeMSec timeout)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
@@ -428,7 +434,7 @@ walSegmentFind(const Storage *storage, const String *archiveId, const String *wa
                 storage, strNewFmt(STORAGE_REPO_ARCHIVE "/%s/%s", strZ(archiveId), strZ(strSubN(walSegment, 0, 16))),
                 .expression = strNewFmt(
                     "^%s%s-[0-f]{40}" COMPRESS_TYPE_REGEXP "{0,1}$", strZ(strSubN(walSegment, 0, 24)),
-                        walIsPartial(walSegment) ? WAL_SEGMENT_PARTIAL_EXT : ""),
+                    walIsPartial(walSegment) ? WAL_SEGMENT_PARTIAL_EXT : ""),
                 .nullOnMissing = true);
 
             // If there are results
@@ -440,7 +446,7 @@ walSegmentFind(const Storage *storage, const String *archiveId, const String *wa
                     THROW_FMT(
                         ArchiveDuplicateError,
                         "duplicates found in archive for WAL segment %s: %s\n"
-                            "HINT: are multiple primaries archiving to this stanza?",
+                        "HINT: are multiple primaries archiving to this stanza?",
                         strZ(walSegment), strZ(strLstJoin(strLstSort(list, sortOrderAsc), ", ")));
                 }
 
@@ -461,9 +467,9 @@ walSegmentFind(const Storage *storage, const String *archiveId, const String *wa
         THROW_FMT(
             ArchiveTimeoutError,
             "WAL segment %s was not archived before the %" PRIu64 "ms timeout\n"
-                "HINT: check the archive_command to ensure that all options are correct (especially --stanza).\n"
-                "HINT: check the PostgreSQL server log for errors.\n"
-                "HINT: run the 'start' command if the stanza was previously stopped.",
+            "HINT: check the archive_command to ensure that all options are correct (especially --stanza).\n"
+            "HINT: check the PostgreSQL server log for errors.\n"
+            "HINT: run the 'start' command if the stanza was previously stopped.",
             strZ(walSegment), timeout);
     }
 
@@ -471,7 +477,7 @@ walSegmentFind(const Storage *storage, const String *archiveId, const String *wa
 }
 
 /**********************************************************************************************************************************/
-String *
+FN_EXTERN String *
 walSegmentNext(const String *walSegment, size_t walSegmentSize, unsigned int pgVersion)
 {
     FUNCTION_LOG_BEGIN(logLevelTrace);
@@ -483,7 +489,7 @@ walSegmentNext(const String *walSegment, size_t walSegmentSize, unsigned int pgV
     ASSERT(walSegment != NULL);
     ASSERT(strSize(walSegment) == 24);
     ASSERT(UINT32_MAX % walSegmentSize == walSegmentSize - 1);
-    ASSERT(pgVersion >= PG_VERSION_11 || walSegmentSize == 16 * 1024 * 1024);
+    ASSERT(pgVersion >= PG_VERSION_11 || walSegmentSize == PG_WAL_SEGMENT_SIZE_DEFAULT);
 
     // Extract WAL parts
     uint32_t timeline = 0;
@@ -492,7 +498,7 @@ walSegmentNext(const String *walSegment, size_t walSegmentSize, unsigned int pgV
 
     MEM_CONTEXT_TEMP_BEGIN()
     {
-        timeline = (uint32_t)strtol(strZ(strSubN(walSegment, 0, 8)), NULL, 16);
+        timeline = pgTimelineFromWalSegment(walSegment);
         major = (uint32_t)strtol(strZ(strSubN(walSegment, 8, 8)), NULL, 16);
         minor = (uint32_t)strtol(strZ(strSubN(walSegment, 16, 8)), NULL, 16);
 
@@ -504,13 +510,6 @@ walSegmentNext(const String *walSegment, size_t walSegmentSize, unsigned int pgV
             major++;
             minor = 0;
         }
-
-        // Special hack for PostgreSQL < 9.3 which skipped minor FF
-        if (minor == 0xFF && pgVersion < PG_VERSION_93)
-        {
-            major++;
-            minor = 0;
-        }
     }
     MEM_CONTEXT_TEMP_END();
 
@@ -518,7 +517,7 @@ walSegmentNext(const String *walSegment, size_t walSegmentSize, unsigned int pgV
 }
 
 /**********************************************************************************************************************************/
-StringList *
+FN_EXTERN StringList *
 walSegmentRange(const String *walSegmentBegin, size_t walSegmentSize, unsigned int pgVersion, unsigned int range)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
