@@ -4,16 +4,16 @@ Socket Client
 #include "build.auto.h"
 
 #include <netinet/in.h>
-#include <sys/types.h>
 #include <sys/socket.h>
+#include <sys/types.h>
 #include <unistd.h>
 
 #include "common/debug.h"
-#include "common/log.h"
 #include "common/io/client.h"
 #include "common/io/socket/client.h"
 #include "common/io/socket/common.h"
 #include "common/io/socket/session.h"
+#include "common/log.h"
 #include "common/stat.h"
 #include "common/type/object.h"
 #include "common/wait.h"
@@ -40,20 +40,20 @@ typedef struct SocketClient
 /***********************************************************************************************************************************
 Macros for function logging
 ***********************************************************************************************************************************/
-static String *
-sckClientToLog(const THIS_VOID)
+static void
+sckClientToLog(const THIS_VOID, StringStatic *const debugLog)
 {
     THIS(const SocketClient);
 
-    return strNewFmt(
-        "{host: %s, port: %u, timeoutConnect: %" PRIu64 ", timeoutSession: %" PRIu64 "}", strZ(this->host), this->port,
+    strStcFmt(
+        debugLog, "{host: %s, port: %u, timeoutConnect: %" PRIu64 ", timeoutSession: %" PRIu64 "}", strZ(this->host), this->port,
         this->timeoutConnect, this->timeoutSession);
 }
 
 #define FUNCTION_LOG_SOCKET_CLIENT_TYPE                                                                                            \
     SocketClient *
 #define FUNCTION_LOG_SOCKET_CLIENT_FORMAT(value, buffer, bufferSize)                                                               \
-    FUNCTION_LOG_STRING_OBJECT_FORMAT(value, sckClientToLog, buffer, bufferSize)
+    FUNCTION_LOG_OBJECT_FORMAT(value, sckClientToLog, buffer, bufferSize)
 
 /**********************************************************************************************************************************/
 static IoSession *
@@ -158,10 +158,10 @@ static const IoClientInterface sckClientInterface =
     .toLog = sckClientToLog,
 };
 
-IoClient *
+FN_EXTERN IoClient *
 sckClientNew(const String *const host, const unsigned int port, const TimeMSec timeoutConnect, const TimeMSec timeoutSession)
 {
-    FUNCTION_LOG_BEGIN(logLevelDebug)
+    FUNCTION_LOG_BEGIN(logLevelDebug);
         FUNCTION_LOG_PARAM(STRING, host);
         FUNCTION_LOG_PARAM(UINT, port);
         FUNCTION_LOG_PARAM(TIME_MSEC, timeoutConnect);
@@ -170,13 +170,9 @@ sckClientNew(const String *const host, const unsigned int port, const TimeMSec t
 
     ASSERT(host != NULL);
 
-    IoClient *this = NULL;
-
-    OBJ_NEW_BEGIN(SocketClient, .childQty = MEM_CONTEXT_QTY_MAX, .allocQty = MEM_CONTEXT_QTY_MAX)
+    OBJ_NEW_BEGIN(SocketClient, .childQty = MEM_CONTEXT_QTY_MAX)
     {
-        SocketClient *driver = OBJ_NEW_ALLOC();
-
-        *driver = (SocketClient)
+        *this = (SocketClient)
         {
             .host = strDup(host),
             .port = port,
@@ -184,12 +180,10 @@ sckClientNew(const String *const host, const unsigned int port, const TimeMSec t
             .timeoutConnect = timeoutConnect,
             .timeoutSession = timeoutSession,
         };
-
-        statInc(SOCKET_STAT_CLIENT_STR);
-
-        this = ioClientNew(driver, &sckClientInterface);
     }
     OBJ_NEW_END();
 
-    FUNCTION_LOG_RETURN(IO_CLIENT, this);
+    statInc(SOCKET_STAT_CLIENT_STR);
+
+    FUNCTION_LOG_RETURN(IO_CLIENT, ioClientNew(this, &sckClientInterface));
 }
