@@ -20,7 +20,7 @@ struct Wait
 };
 
 /**********************************************************************************************************************************/
-Wait *
+FN_EXTERN Wait *
 waitNew(TimeMSec waitTime)
 {
     FUNCTION_LOG_BEGIN(logLevelTrace);
@@ -29,14 +29,8 @@ waitNew(TimeMSec waitTime)
 
     ASSERT(waitTime <= 999999000);
 
-    // Allocate wait object
-    Wait *this = NULL;
-
     OBJ_NEW_BEGIN(Wait, .childQty = MEM_CONTEXT_QTY_MAX)
     {
-        // Create object
-        this = OBJ_NEW_ALLOC();
-
         *this = (Wait)
         {
             .pub =
@@ -62,7 +56,7 @@ waitNew(TimeMSec waitTime)
 }
 
 /**********************************************************************************************************************************/
-bool
+FN_EXTERN bool
 waitMore(Wait *this)
 {
     FUNCTION_LOG_BEGIN(logLevelTrace);
