@@ -10,19 +10,20 @@ Configuration Load
 #include "command/command.h"
 #include "common/compress/helper.intern.h"
 #include "common/crypto/common.h"
-#include "common/memContext.h"
 #include "common/debug.h"
 #include "common/io/io.h"
 #include "common/io/socket/common.h"
 #include "common/lock.h"
 #include "common/log.h"
+#include "common/memContext.h"
 #include "config/config.intern.h"
 #include "config/load.h"
 #include "config/parse.h"
 #include "info/infoBackup.h"
 #include "storage/cifs/storage.h"
-#include "storage/posix/storage.h"
 #include "storage/helper.h"
+#include "storage/posix/storage.h"
+#include "storage/sftp/storage.h"
 
 /***********************************************************************************************************************************
 Load log settings
@@ -62,11 +63,13 @@ cfgLoadLogSetting(void)
 }
 
 /**********************************************************************************************************************************/
-void
+FN_EXTERN void
 cfgLoadUpdateOption(void)
 {
     FUNCTION_LOG_VOID(logLevelTrace);
 
+    FUNCTION_AUDIT_HELPER();
+
     // Make sure the repo option is set for the stanza-delete command when more than one repo is configured or the first configured
     // repo is not key 1.
     if (!cfgCommandHelp() && cfgOptionValid(cfgOptRepo) && cfgCommand() == cfgCmdStanzaDelete &&
@@ -84,9 +87,10 @@ cfgLoadUpdateOption(void)
     {
         for (unsigned int optionIdx = 0; optionIdx < cfgOptionGroupIdxTotal(cfgOptGrpRepo); optionIdx++)
         {
-            // If the repo is local and either posix or cifs
+            // If the repo is local and either posix, cifs or sftp
             if (!cfgOptionIdxTest(cfgOptRepoHost, optionIdx) &&
                 (cfgOptionIdxStrId(cfgOptRepoType, optionIdx) == STORAGE_POSIX_TYPE ||
+                 cfgOptionIdxStrId(cfgOptRepoType, optionIdx) == STORAGE_SFTP_TYPE ||
                  cfgOptionIdxStrId(cfgOptRepoType, optionIdx) == STORAGE_CIFS_TYPE))
             {
                 // Ensure a local repo does not have the same path as another local repo of the same type
@@ -147,7 +151,7 @@ cfgLoadUpdateOption(void)
             THROW_FMT(
                 OptionInvalidValueError,
                 "'%s' is not valid for '" CFGOPT_PROTOCOL_TIMEOUT "' option\nHINT '" CFGOPT_PROTOCOL_TIMEOUT "' option (%s)"
-                    " should be greater than '" CFGOPT_DB_TIMEOUT "' option (%s).",
+                " should be greater than '" CFGOPT_DB_TIMEOUT "' option (%s).",
                 strZ(cfgOptionDisplay(cfgOptProtocolTimeout)), strZ(cfgOptionDisplay(cfgOptProtocolTimeout)),
                 strZ(cfgOptionDisplay(cfgOptDbTimeout)));
         }
@@ -217,11 +221,11 @@ cfgLoadUpdateOption(void)
                 {
                     case backupTypeFull:
                     {
-                        if (cfgOptionIdxStrId(cfgOptRepoRetentionFullType, optionIdx) ==
-                                CFGOPTVAL_REPO_RETENTION_FULL_TYPE_COUNT &&
+                        if (cfgOptionIdxStrId(cfgOptRepoRetentionFullType, optionIdx) == CFGOPTVAL_REPO_RETENTION_FULL_TYPE_COUNT &&
                             cfgOptionIdxTest(cfgOptRepoRetentionFull, optionIdx))
                         {
-                            cfgOptionIdxSet(cfgOptRepoRetentionArchive, optionIdx, cfgSourceDefault,
+                            cfgOptionIdxSet(
+                                cfgOptRepoRetentionArchive, optionIdx, cfgSourceDefault,
                                 VARINT64(cfgOptionIdxInt64(cfgOptRepoRetentionFull, optionIdx)));
                         }
 
@@ -233,7 +237,8 @@ cfgLoadUpdateOption(void)
                         // if repo-retention-diff is set then user must have set it
                         if (cfgOptionIdxTest(cfgOptRepoRetentionDiff, optionIdx))
                         {
-                            cfgOptionIdxSet(cfgOptRepoRetentionArchive, optionIdx, cfgSourceDefault,
+                            cfgOptionIdxSet(
+                                cfgOptRepoRetentionArchive, optionIdx, cfgSourceDefault,
                                 VARINT64(cfgOptionIdxInt64(cfgOptRepoRetentionDiff, optionIdx)));
                         }
                         else
@@ -280,14 +285,28 @@ cfgLoadUpdateOption(void)
         {
             THROW_FMT(
                 OptionInvalidValueError,
-                "'%s' is not valid for option '%s'"
-                    "\nHINT: RFC-2818 forbids dots in wildcard matches."
-                    "\nHINT: TLS/SSL verification cannot proceed with this bucket name."
-                    "\nHINT: remove dots from the bucket name.",
+                "'%s' is not valid for option '%s'\n"
+                "HINT: RFC-2818 forbids dots in wildcard matches.\n"
+                "HINT: TLS/SSL verification cannot proceed with this bucket name.\n"
+                "HINT: remove dots from the bucket name.",
                 strZ(cfgOptionIdxDisplay(cfgOptRepoS3Bucket, repoIdx)), cfgOptionIdxName(cfgOptRepoS3Bucket, repoIdx));
         }
     }
 
+    // Set default upload chunk size if not set
+    if (cfgOptionValid(cfgOptRepoStorageUploadChunkSize))
+    {
+        for (unsigned int repoIdx = 0; repoIdx < cfgOptionGroupIdxTotal(cfgOptGrpRepo); repoIdx++)
+        {
+            if (!cfgOptionIdxTest(cfgOptRepoStorageUploadChunkSize, repoIdx))
+            {
+                cfgOptionIdxSet(
+                    cfgOptRepoStorageUploadChunkSize, repoIdx, cfgSourceDefault,
+                    VARINT64((cfgOptionIdxStrId(cfgOptRepoType, repoIdx) == CFGOPTVAL_REPO_TYPE_S3 ? 5 : 4) * 1024 * 1024));
+            }
+        }
+    }
+
     // Set pg-host-port/repo-host-port default when pg-host-type/repo-host-type is tls. ??? This should be handled in the parser but
     // it requires a default that depends on another option value and that is not currently possible.
     #define HOST_PORT_TLS                                           8432
@@ -339,56 +358,77 @@ cfgLoadUpdateOption(void)
         cfgOptionSet(cfgOptCompress, cfgSourceDefault, NULL);
     }
 
-    // Check that selected compress type has been compiled into this binary
-    if (cfgOptionValid(cfgOptCompressType))
-        compressTypePresent(compressTypeEnum(cfgOptionStrId(cfgOptCompressType)));
-
-    // Update compress-level default based on the compression type
-    if (cfgOptionValid(cfgOptCompressLevel) && cfgOptionSource(cfgOptCompressLevel) == cfgSourceDefault)
+    // Update compress-level default based on the compression type. Also check that level range is valid per compression type.
+    if (cfgOptionValid(cfgOptCompressLevel))
     {
-        cfgOptionSet(
-            cfgOptCompressLevel, cfgSourceDefault,
-            VARINT64(compressLevelDefault(compressTypeEnum(cfgOptionStrId(cfgOptCompressType)))));
+        const CompressType compressType = compressTypeEnum(cfgOptionStrId(cfgOptCompressType));
+
+        if (cfgOptionSource(cfgOptCompressLevel) == cfgSourceDefault)
+        {
+            cfgOptionSet(cfgOptCompressLevel, cfgSourceDefault, VARINT64(compressLevelDefault(compressType)));
+        }
+        else if (compressType != compressTypeNone)
+        {
+            if (cfgOptionInt(cfgOptCompressLevel) < compressLevelMin(compressType) ||
+                cfgOptionInt(cfgOptCompressLevel) > compressLevelMax(compressType))
+            {
+                THROW_FMT(
+                    OptionInvalidValueError,
+                    "'%d' is out of range for '" CFGOPT_COMPRESS_LEVEL "' option when '" CFGOPT_COMPRESS_TYPE "' option = '%s'",
+                    cfgOptionInt(cfgOptCompressLevel), strZ(strIdToStr(cfgOptionStrId(cfgOptCompressType))));
+            }
+        }
     }
 
     FUNCTION_LOG_RETURN_VOID();
 }
 
 /**********************************************************************************************************************************/
-void
+FN_EXTERN String *
+cfgLoadLogFileName(const ConfigCommandRole commandRole)
+{
+    FUNCTION_LOG_BEGIN(logLevelTrace);
+        FUNCTION_LOG_PARAM(ENUM, commandRole);
+    FUNCTION_LOG_END();
+
+    // Construct log filename prefix
+    String *const result = strCatFmt(
+        strNew(),
+        "%s/%s-%s", strZ(cfgOptionStr(cfgOptLogPath)),
+        cfgOptionTest(cfgOptStanza) ? strZ(cfgOptionStr(cfgOptStanza)) : "all", cfgCommandName());
+
+    // ??? Append async for local/remote archive async commands. It would be good to find a more generic way to do this in case the
+    // async role is added to more commands.
+    if (commandRole == cfgCmdRoleLocal || commandRole == cfgCmdRoleRemote)
+    {
+        if (cfgOptionValid(cfgOptArchiveAsync) && cfgOptionBool(cfgOptArchiveAsync))
+            strCatZ(result, "-async");
+    }
+
+    // Add command role if it is not main
+    if (commandRole != cfgCmdRoleMain)
+        strCatFmt(result, "-%s", strZ(cfgParseCommandRoleStr(commandRole)));
+
+    // Add process id if local or remote role
+    if (commandRole == cfgCmdRoleLocal || commandRole == cfgCmdRoleRemote)
+        strCatFmt(result, "-%03u", cfgOptionUInt(cfgOptProcess));
+
+    // Add extension
+    strCatZ(result, ".log");
+
+    FUNCTION_LOG_RETURN(STRING, result);
+}
+
+/**********************************************************************************************************************************/
+FN_EXTERN void
 cfgLoadLogFile(void)
 {
     if (cfgLogFile() && !cfgCommandHelp())
     {
         MEM_CONTEXT_TEMP_BEGIN()
         {
-            // Construct log filename prefix
-            String *logFile = strCatFmt(
-                strNew(),
-                "%s/%s-%s", strZ(cfgOptionStr(cfgOptLogPath)),
-                cfgOptionTest(cfgOptStanza) ? strZ(cfgOptionStr(cfgOptStanza)): "all", cfgCommandName());
-
-            // ??? Append async for local/remote archive async commands.  It would be good to find a more generic way to do this in
-            // case the async role is added to more commands.
-            if (cfgCommandRole() == cfgCmdRoleLocal || cfgCommandRole() == cfgCmdRoleRemote)
-            {
-                if (cfgOptionValid(cfgOptArchiveAsync) && cfgOptionBool(cfgOptArchiveAsync))
-                    strCatFmt(logFile, "-async");
-            }
-
-            // Add command role if it is not main
-            if (cfgCommandRole() != cfgCmdRoleMain)
-                strCatFmt(logFile, "-%s", strZ(cfgParseCommandRoleStr(cfgCommandRole())));
-
-            // Add process id if local or remote role
-            if (cfgCommandRole() == cfgCmdRoleLocal || cfgCommandRole() == cfgCmdRoleRemote)
-                strCatFmt(logFile, "-%03u", cfgOptionUInt(cfgOptProcess));
-
-            // Add extension
-            strCatZ(logFile, ".log");
-
             // Attempt to open log file
-            if (!logFileSet(strZ(logFile)))
+            if (!logFileSet(strZ(cfgLoadLogFileName(cfgCommandRole()))))
                 cfgOptionSet(cfgOptLogLevelFile, cfgSourceParam, VARUINT64(CFGOPTVAL_LOG_LEVEL_CONSOLE_OFF));
         }
         MEM_CONTEXT_TEMP_END();
@@ -396,7 +436,7 @@ cfgLoadLogFile(void)
 }
 
 /**********************************************************************************************************************************/
-void
+FN_EXTERN void
 cfgLoad(unsigned int argListSize, const char *argList[])
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
@@ -407,7 +447,7 @@ cfgLoad(unsigned int argListSize, const char *argList[])
     MEM_CONTEXT_TEMP_BEGIN()
     {
         // Parse config from command line and config file
-        configParse(storageLocal(), argListSize, argList, true);
+        cfgParseP(storageLocal(), argListSize, argList);
 
         // Initialize dry-run mode for storage when valid for the current command
         storageHelperDryRunInit(cfgOptionValid(cfgOptDryRun) && cfgOptionBool(cfgOptDryRun));
@@ -459,11 +499,14 @@ cfgLoad(unsigned int argListSize, const char *argList[])
             // Begin the command
             cmdBegin();
 
-            // Acquire a lock if this command requires a lock
-            if (cfgLockRequired() && !cfgCommandHelp())
+            // Init lock module if this command can lock
+            if (cfgLockType() != lockTypeNone && !cfgCommandHelp())
             {
-                lockAcquire(
-                    cfgOptionStr(cfgOptLockPath), cfgOptionStr(cfgOptStanza), cfgOptionStr(cfgOptExecId), cfgLockType(), 0, true);
+                lockInit(cfgOptionStr(cfgOptLockPath), cfgOptionStr(cfgOptExecId), cfgOptionStr(cfgOptStanza), cfgLockType());
+
+                // Acquire a lock if this command requires a lock
+                if (cfgLockRequired())
+                    lockAcquireP();
             }
 
             // Update options that have complex rules
