@@ -131,9 +131,10 @@ sub containerWrite
 
     # Write the image
     $oStorageDocker->put("${strTempPath}/${strImage}", trim($strScript) . "\n");
-    executeTest('docker build' . (defined($bForce) && $bForce ? ' --no-cache' : '') .
-                " -f ${strTempPath}/${strImage} -t ${strTag} ${strTempPath}",
-                {bSuppressStdErr => true});
+    executeTest(
+        'docker build' . (defined($bForce) && $bForce ? ' --no-cache' : '') . " -f ${strTempPath}/${strImage} -t ${strTag} " .
+            $oStorageDocker->pathGet('test'),
+        {bSuppressStdErr => true, bShowOutputAsync => (logLevel())[1] eq DETAIL});
 }
 
 ####################################################################################################################################
@@ -214,6 +215,7 @@ sub sshSetup
     }
 
     $strScript .=
+        "    cp ${strUserPath}/.ssh/authorized_keys ${strUserPath}/.ssh/id_rsa.pub && \\\n" .
         "    chown -R ${strUser}:${strGroup} ${strUserPath}/.ssh && \\\n" .
         "    chmod 700 ${strUserPath}/.ssh && \\\n" .
         "    chmod 600 ${strUserPath}/.ssh/*";
@@ -282,7 +284,7 @@ sub caSetup
         $strScript .=
             "    update-ca-trust extract";
     }
-    elsif ($strOsBase  eq VM_OS_BASE_DEBIAN)
+    elsif ($strOsBase eq VM_OS_BASE_DEBIAN)
     {
         $strScript .=
             "    update-ca-certificates";
@@ -384,7 +386,8 @@ sub containerBuild
                 "    yum -y install openssh-server openssh-clients wget sudo valgrind git \\\n" .
                 "        perl perl-Digest-SHA perl-DBD-Pg perl-YAML-LibYAML openssl \\\n" .
                 "        gcc make perl-ExtUtils-MakeMaker perl-Test-Simple openssl-devel perl-ExtUtils-Embed rpm-build \\\n" .
-                "        libyaml-devel zlib-devel libxml2-devel lz4-devel lz4 bzip2-devel bzip2 perl-JSON-PP";
+                "        libyaml-devel zlib-devel libxml2-devel lz4-devel lz4 bzip2-devel bzip2 perl-JSON-PP ccache meson \\\n" .
+                "        libssh2-devel";
         }
         else
         {
@@ -395,13 +398,19 @@ sub containerBuild
                 "        libdbd-pg-perl libhtml-parser-perl libssl-dev libperl-dev \\\n" .
                 "        libyaml-libyaml-perl tzdata devscripts lintian libxml-checker-perl txt2man debhelper \\\n" .
                 "        libppi-html-perl libtemplate-perl libtest-differences-perl zlib1g-dev libxml2-dev pkg-config \\\n" .
-                "        libbz2-dev bzip2 libyaml-dev libjson-pp-perl liblz4-dev liblz4-tool gnupg";
+                "        libbz2-dev bzip2 libyaml-dev libjson-pp-perl liblz4-dev liblz4-tool gnupg lsb-release ccache meson \\\n" .
+                "        libssh2-1-dev";
 
             # This package is required to build valgrind on 32-bit
             if ($oVm->{$strOS}{&VM_ARCH} eq VM_ARCH_I386)
             {
                 $strScript .= " g++-multilib";
             }
+
+            if ($strOS eq VM_U22)
+            {
+                $strScript .= " valgrind";
+            }
         }
 
         # Add zst command-line tool and development libs when available
@@ -441,15 +450,18 @@ sub containerBuild
         }
 
         #---------------------------------------------------------------------------------------------------------------------------
-        my $strValgrind = 'valgrind-3.17.0';
+        if ($strOS ne VM_U22)
+        {
+            my $strValgrind = 'valgrind-3.17.0';
 
-        $strScript .= sectionHeader() .
-            "# Build valgrind\n" .
-            "    wget -q -O - https://sourceware.org/pub/valgrind/${strValgrind}.tar.bz2 | tar jx -C /root && \\\n" .
-            "    cd /root/${strValgrind} && \\\n" .
-            "    ./configure --silent && \\\n" .
-            "    make -s -j8 install && \\\n" .
-            "    rm -rf /root/${strValgrind}";
+            $strScript .= sectionHeader() .
+                "# Build valgrind\n" .
+                "    wget -q -O - https://sourceware.org/pub/valgrind/${strValgrind}.tar.bz2 | tar jx -C /root && \\\n" .
+                "    cd /root/${strValgrind} && \\\n" .
+                "    ./configure --silent && \\\n" .
+                "    make -s -j8 install && \\\n" .
+                "    rm -rf /root/${strValgrind}";
+        }
 
         #---------------------------------------------------------------------------------------------------------------------------
         if (defined($oVm->{$strOS}{&VMDEF_LCOV_VERSION}))
@@ -468,7 +480,7 @@ sub containerBuild
         #---------------------------------------------------------------------------------------------------------------------------
         if (!$bDeprecated)
         {
-            $strScript .=  sectionHeader() .
+            $strScript .= sectionHeader() .
                 "# Install PostgreSQL packages\n";
 
             if ($$oVm{$strOS}{&VM_OS_BASE} eq VM_OS_BASE_RHEL)
@@ -483,11 +495,11 @@ sub containerBuild
                         "        https://download.postgresql.org/pub/repos/yum/reporpms/EL-7-" . hostArch() . "/" .
                             "pgdg-redhat-repo-latest.noarch.rpm && \\\n";
                 }
-                elsif ($strOS eq VM_F33)
+                elsif ($strOS eq VM_F38)
                 {
                     $strScript .=
                         "    rpm -ivh \\\n" .
-                        "        https://download.postgresql.org/pub/repos/yum/reporpms/F-33-" . hostArch() . "/" .
+                        "        https://download.postgresql.org/pub/repos/yum/reporpms/F-38-" . hostArch() . "/" .
                             "pgdg-fedora-repo-latest.noarch.rpm && \\\n";
                 }
 
@@ -496,8 +508,8 @@ sub containerBuild
             else
             {
                 $strScript .=
-                    "    echo 'deb http://apt.postgresql.org/pub/repos/apt/ " .
-                    $$oVm{$strOS}{&VM_OS_REPO} . '-pgdg main' . "' >> /etc/apt/sources.list.d/pgdg.list && \\\n" .
+                    "    echo \"deb http://apt.postgresql.org/pub/repos/apt/ \$(lsb_release -s -c)-pgdg main" .
+                        ($strOS eq VM_U22 ? ' 16' : '') . "\" >> /etc/apt/sources.list.d/pgdg.list && \\\n" .
                     "    wget --quiet -O - https://www.postgresql.org/media/keys/ACCC4CF8.asc | apt-key add - && \\\n" .
                     "    apt-get update && \\\n" .
                     "    apt-get install -y --no-install-recommends postgresql-common libpq-dev && \\\n" .
@@ -517,7 +529,7 @@ sub containerBuild
                 else
                 {
                     $strScript .= "    apt-get install -y --no-install-recommends";
-                }
+                 }
 
                 # Construct list of databases to install
                 foreach my $strDbVersion (@{$oOS->{&VM_DB}})
@@ -527,12 +539,12 @@ sub containerBuild
                         my $strDbVersionNoDot = $strDbVersion;
                         $strDbVersionNoDot =~ s/\.//;
 
-                        $strScript .=  " postgresql${strDbVersionNoDot}-server";
+                        $strScript .= " postgresql${strDbVersionNoDot}-server";
 
                         # Add development package for the latest version of postgres
                         if ($strDbVersion eq @{$oOS->{&VM_DB}}[-1])
                         {
-                            $strScript .=  " postgresql${strDbVersionNoDot}-devel";
+                            $strScript .= " postgresql${strDbVersionNoDot}-devel";
                         }
                     }
                     else
@@ -547,13 +559,14 @@ sub containerBuild
         if ($$oVm{$strOS}{&VM_OS_BASE} eq VM_OS_BASE_RHEL)
         {
             $strScript .=
-                "\n\nENV PATH=/usr/pgsql-" . @{$oOS->{&VM_DB}}[-1] . "/bin:\$PATH\n";
+                "\n\nENV PATH=/usr/pgsql-" . @{$oOS->{&VM_DB}}[-1] . "/bin:\$PATH\n" .
+                "ENV PKG_CONFIG_PATH=/usr/pgsql-" . @{$oOS->{&VM_DB}}[-1] . "/lib/pkgconfig:\$PKG_CONFIG_PATH\n";
         }
 
         #---------------------------------------------------------------------------------------------------------------------------
         if ($$oVm{$strOS}{&VM_OS_BASE} eq VM_OS_BASE_DEBIAN)
         {
-        $strScript .=  sectionHeader() .
+        $strScript .= sectionHeader() .
             "# Cleanup\n";
 
             $strScript .=
@@ -596,6 +609,14 @@ sub containerBuild
                 "    echo '***********************************************' >> /etc/issue.net && \\\n" .
                 "    echo 'Banner /etc/issue.net'                           >> /etc/ssh/sshd_config";
 
+            if ($strOS eq VM_U22)
+            {
+                $strScript .= sectionHeader() .
+                    "    echo '# Add PubkeyAcceptedAlgorithms (required for SFTP)'              >> /etc/ssh/sshd_config && \\\n" .
+                    "    echo 'HostKeyAlgorithms=+ssh-rsa,ssh-rsa-cert-v01\@openssh.com'        >> /etc/ssh/sshd_config && \\\n" .
+                    "    echo 'PubkeyAcceptedAlgorithms=+ssh-rsa,ssh-rsa-cert-v01\@openssh.com' >> /etc/ssh/sshd_config";
+            }
+
             $strScript .= sectionHeader() .
                 "# Create test user\n" .
                 '    ' . groupCreate($strOS, TEST_GROUP, TEST_GROUP_ID) . " && \\\n" .
@@ -624,7 +645,7 @@ sub containerBuild
             $strScript .=
                 sshSetup($strOS, TEST_USER, TEST_GROUP, $$oVm{$strOS}{&VM_CONTROL_MTR});
 
-            $strScript .=  sectionHeader() .
+            $strScript .= sectionHeader() .
                 "# Make " . TEST_USER . " home dir readable\n" .
                 '    chmod g+r,g+x /home/' . TEST_USER;
 
