@@ -39,7 +39,7 @@ sub coverageLCovConfigGenerate
     my $bCoverageSummary = shift;
 
     my $strBranchFilter =
-        'OBJECT_DEFINE_[A-Z0-9_]+\(|\s{4}[A-Z][A-Z0-9_]+\([^\?]*\)|\s{4}(ASSERT|assert|switch\s)\(|\{\+{0,1}' .
+        'OBJECT_DEFINE_[A-Z0-9_]+\(|\s{4}[A-Z][A-Z0-9_]+\([^\?]*\)|\s{4}(ASSERT|CHECK|CHECK_FMT|assert|switch\s)\(|\{\+{0,1}' .
         ($bCoverageSummary ? 'uncoverable_branch' : 'uncover(ed|able)_branch');
     my $strLineFilter =
         '\{\+{0,1}' . ($bCoverageSummary ? 'uncoverable' : '(uncover(ed|able)' . ($bContainer ? '' : '|vm_covered') . ')') . '[^_]';
@@ -54,7 +54,7 @@ sub coverageLCovConfigGenerate
         "#\n" .
         '# OBJECT_DEFINE_[A-Z0-9_]+\( - exclude object definitions' . "\n" .
         '# \s{4}[A-Z][A-Z0-9_]+\([^\?]*\) - exclude macros that do not take a conditional parameter and are not themselves a parameter' . "\n" .
-        '# ASSERT/(|assert\( - exclude asserts since it usually not possible to trigger both branches' . "\n" .
+        '# ASSERT/(|CHECK/(|assert\( - exclude asserts/checks since it usually not possible to trigger both branches' . "\n" .
         '# switch \( - lcov requires default: to show complete coverage but --Wswitch-enum enforces all enum values be present' . "\n" .
         "lcov_excl_br_line=${strBranchFilter}\n" .
         "\n" .
@@ -118,12 +118,18 @@ sub coverageExtract
 
     executeTest(
         (defined($strContainerImage) ? 'docker exec -i -u ' . TEST_USER . " ${strContainerImage} " : '') .
-        "${strLCovExe} --capture --directory=${strWorkUnitPath} --o=${strLCovOut}");
+        "${strLCovExe} --capture --directory=${strWorkUnitPath} --o=${strLCovOut} 2>&1");
 
     # Generate coverage report for each module
     foreach my $strCoveredModule (@stryCoveredModule)
     {
         my $strModuleName = testRunName($strCoveredModule, false);
+
+        if ($strModuleName =~ /^test/mg)
+        {
+            $strModuleName =~ s/^test/src/mg;
+        }
+
         my $strModuleOutName = $strModuleName;
         my $bTest = false;
 
@@ -134,22 +140,35 @@ sub coverageExtract
         }
 
         # Generate lcov reports
-        my $strModulePath =
-            "${strWorkPath}/repo/" .
-            (${strModuleOutName} =~ /^test\// ?
-                'test/src/module/' . substr(${strModuleOutName}, 5) : "src/${strModuleOutName}");
+        my $strModulePath = "${strWorkPath}/repo/";
+
+        if (${strModuleOutName} =~ /^src\//)
+        {
+            $strModulePath .= 'test/src/' . substr(${strModuleOutName}, 4);
+        }
+        elsif (${strModuleOutName} =~ /^test\//)
+        {
+            $strModulePath .= 'test/src/module/' . substr(${strModuleOutName}, 5);
+        }
+        else
+        {
+            $strModulePath .= "src/${strModuleOutName}";
+        }
+
         my $strLCovFile = "${strTestResultCoveragePath}/raw/${strModuleOutName}.lcov";
         my $strLCovTotal = "${strWorkTmpPath}/all.lcov";
+        my $bInc = $strModuleName =~ '\.vendor$' || $strModuleName =~ '\.auto$';
+        my $strModuleSourceFile = $strModulePath . '.c' . ($bInc ? '.inc' : '');
 
         executeTest(
             "${strLCovExe}" . ($bTest ? ' --rc lcov_branch_coverage=0' : '') . " --extract=${strLCovOut} */${strModuleName}.c" .
-                " --o=${strLCovOutTmp}");
+            ($bInc ? '.inc' : '') . " --o=${strLCovOutTmp}");
 
         # Combine with prior run if there was one
         if ($oStorage->exists($strLCovFile))
         {
             my $strCoverage = ${$oStorage->get($strLCovOutTmp)};
-            $strCoverage =~ s/^SF\:.*$/SF:$strModulePath\.c/mg;
+            $strCoverage =~ s/^SF\:.*$/SF:$strModuleSourceFile/mg;
             $oStorage->put($strLCovOutTmp, $strCoverage);
 
             executeTest("${strLCovExe} --add-tracefile=${strLCovOutTmp} --add-tracefile=${strLCovFile} --o=${strLCovOutTmp}");
@@ -185,7 +204,7 @@ sub coverageExtract
             if (!$bTest || $iTotalLines != $iCoveredLines || $iTotalBranches != $iCoveredBranches)
             {
                 # Fix source file name
-                $strCoverage =~ s/^SF\:.*$/SF:$strModulePath\.c/mg;
+                $strCoverage =~ s/^SF\:.*$/SF:$strModuleSourceFile/mg;
 
                 $oStorage->put($oStorage->openWrite($strLCovFile, {bPathCreate => true}), $strCoverage);
 
@@ -222,6 +241,7 @@ sub coverageValidateAndGenerate
 {
     my $oyTestRun = shift;
     my $oStorage = shift;
+    my $bCoverageReport = shift;
     my $bCoverageSummary = shift;
     my $strWorkPath = shift;
     my $strWorkTmpPath = shift;
@@ -287,20 +307,14 @@ sub coverageValidateAndGenerate
 
     # Generate C coverage report
     #---------------------------------------------------------------------------------------------------------------------------
-    &log(INFO, 'writing C coverage report');
-
     my $strLCovFile = "${strWorkTmpPath}/all.lcov";
 
     if ($oStorage->exists($strLCovFile))
     {
-        executeTest(
-            "genhtml ${strLCovFile} --config-file=${strTestResultCoveragePath}/raw/lcov.conf" .
-                " --prefix=${strWorkPath}/repo" .
-                " --output-directory=${strTestResultCoveragePath}/lcov");
-
         foreach my $strCodeModule (sort(keys(%{$hCoverageActual})))
         {
             my $strCoverageFile = $strCodeModule;
+            $strCoverageFile =~ s/^test/src/mg;
             $strCoverageFile =~ s/^module/test/mg;
             $strCoverageFile = "${strTestResultCoveragePath}/raw/${strCoverageFile}.lcov";
 
@@ -344,8 +358,23 @@ sub coverageValidateAndGenerate
             }
         }
 
-        coverageGenerate(
-            $oStorage, "${strWorkPath}/repo", "${strTestResultCoveragePath}/raw", "${strTestResultCoveragePath}/coverage.html");
+        if ($result == 0)
+        {
+            &log(INFO, "tested modules have full coverage");
+        }
+
+        if ($bCoverageReport)
+        {
+            &log(INFO, 'writing C coverage report');
+
+            executeTest(
+                "genhtml ${strLCovFile} --config-file=${strTestResultCoveragePath}/raw/lcov.conf" .
+                    " --prefix=${strWorkPath}/repo" .
+                    " --output-directory=${strTestResultCoveragePath}/lcov");
+
+            coverageGenerate(
+                $oStorage, "${strWorkPath}/repo", "${strTestResultCoveragePath}/raw", "${strTestResultCoveragePath}/coverage.html");
+        }
 
         if ($bCoverageSummary)
         {
@@ -355,9 +384,11 @@ sub coverageValidateAndGenerate
                 $oStorage, "${strTestResultCoveragePath}/raw", "${strTestResultSummaryPath}/metric-coverage-report.auto.xml");
         }
     }
-    else
+
+    # Remove coverage report when no coverage or no report to avoid confusion from looking at an old report
+    if (!$bCoverageReport || !$oStorage->exists($strLCovFile))
     {
-        executeTest("rm -rf ${strTestResultCoveragePath}/test/tesult/coverage");
+        executeTest("rm -rf ${strTestResultCoveragePath}");
     }
 
     return $result;
@@ -426,8 +457,8 @@ sub coverageGenerate
                     $strFile = substr($strLine, 3);
                     $rhCoverage->{$strFile} = undef;
 
-                    # Generate a random anchor so new reports will not show links as already followed.  This is also an easy way
-                    # to create valid, disambiguos links.
+                    # Generate a random anchor so new reports will not show links as already followed. This is also an easy way to
+                    # create valid, disambiguos links.
                     $rhCoverage->{$strFile}{anchor} = sha1_hex(rand(16));
                 }
                 # Mark functions as initially covered
@@ -909,7 +940,8 @@ sub coverageDocSummaryGenerate
 
     foreach my $strFileCov (sort(keys(%{$rhManifest})))
     {
-        next if $strFileCov =~ /^test\//;
+        # Skip test modules (this includes modules that start with src/ since src/ is stripped from core modules)
+        next if $strFileCov =~ /^test\// || $strFileCov =~ /^src\//;
 
         if ($strFileCov =~ /\.lcov$/)
         {
