@@ -70,6 +70,10 @@ sub setup
     {
         $oHostObject = new pgBackRestTest::Env::Host::HostGcsTest();
     }
+    elsif ($oConfigParam->{strStorage} eq SFTP)
+    {
+        $oHostObject = new pgBackRestTest::Env::Host::HostSftpTest();
+    }
 
     # Get host group
     my $oHostGroup = hostGroupGet();
@@ -132,7 +136,7 @@ sub setup
     {
         $oHostGroup->hostAdd($oHostObject, {rstryHostName => ['pgbackrest-dev.s3.amazonaws.com', 's3.amazonaws.com']});
     }
-    elsif ($oConfigParam->{strStorage} eq AZURE || $oConfigParam->{strStorage} eq GCS)
+    elsif ($oConfigParam->{strStorage} eq AZURE || $oConfigParam->{strStorage} eq GCS || $oConfigParam->{strStorage} eq SFTP)
     {
         $oHostGroup->hostAdd($oHostObject);
     }
@@ -146,7 +150,8 @@ sub setup
         bArchiveAsync => $$oConfigParam{bArchiveAsync},
         strStorage => $oConfigParam->{strStorage},
         iRepoTotal => $oConfigParam->{iRepoTotal},
-        bBundle => $oConfigParam->{bBundle}});
+        bBundle => $oConfigParam->{bBundle},
+        bBlockIncr => $oConfigParam->{bBlockIncr}});
 
     # Create backup config if backup host exists
     if (defined($oHostBackup))
@@ -157,12 +162,14 @@ sub setup
             bHardlink => $$oConfigParam{bHardLink},
             strStorage => $oConfigParam->{strStorage},
             iRepoTotal => $oConfigParam->{iRepoTotal},
-            bBundle => $oConfigParam->{bBundle}});
+            bBundle => $oConfigParam->{bBundle},
+            bBlockIncr => $oConfigParam->{bBlockIncr}});
     }
     # If backup host is not defined set it to db-primary
     else
     {
-        $oHostBackup = $strBackupDestination eq HOST_DB_PRIMARY ? $oHostDbPrimary : $oHostDbStandby;
+        $oHostBackup = $strBackupDestination eq HOST_DB_PRIMARY || $strBackupDestination eq HOST_SFTP ? $oHostDbPrimary :
+            $oHostDbStandby;
     }
 
     storageRepoCommandSet(
@@ -170,7 +177,8 @@ sub setup
             ' --config=' . $oHostBackup->backrestConfig() . ' --stanza=' . $self->stanza() . ' --log-level-console=off' .
             ' --log-level-stderr=error' .
             ($oConfigParam->{strStorage} ne POSIX ?
-                " --no-repo1-storage-verify-tls --repo1-$oConfigParam->{strStorage}-" .
+                ($oConfigParam->{strStorage} ne SFTP ? " --no-repo1-storage-verify-tls" : '') .
+                " --repo1-$oConfigParam->{strStorage}-" .
                 ($oConfigParam->{strStorage} eq GCS ? 'endpoint' : 'host') . "=" . $oHostObject->ipGet() : '') .
                 ($oConfigParam->{strStorage} eq GCS ? ':' . HOST_GCS_PORT : ''),
         $oConfigParam->{strStorage} eq POSIX ? STORAGE_POSIX : STORAGE_OBJECT);
@@ -186,7 +194,8 @@ sub setup
             bArchiveAsync => $$oConfigParam{bArchiveAsync},
             strStorage => $oConfigParam->{strStorage},
             iRepoTotal => $oConfigParam->{iRepoTotal},
-            bBundle => $oConfigParam->{bBundle}});
+            bBundle => $oConfigParam->{bBundle},
+            bBlockIncr => $oConfigParam->{bBlockIncr}});
     }
 
     # Create object storage
@@ -241,9 +250,6 @@ sub dbCatalogVersion
 
     my $hCatalogVersion =
     {
-        &PG_VERSION_90 => 201008051,
-        &PG_VERSION_91 => 201105231,
-        &PG_VERSION_92 => 201204301,
         &PG_VERSION_93 => 201306121,
         &PG_VERSION_94 => 201409291,
         &PG_VERSION_95 => 201510051,
@@ -253,7 +259,8 @@ sub dbCatalogVersion
         &PG_VERSION_12 => 201909212,
         &PG_VERSION_13 => 202007201,
         &PG_VERSION_14 => 202105121,
-        &PG_VERSION_15 => 202204076,
+        &PG_VERSION_15 => 202209061,
+        &PG_VERSION_16 => 202304110,
     };
 
     if (!defined($hCatalogVersion->{$strPgVersion}))
@@ -285,9 +292,6 @@ sub dbControlVersion
 
     my $hControlVersion =
     {
-        &PG_VERSION_90 => 903,
-        &PG_VERSION_91 => 903,
-        &PG_VERSION_92 => 922,
         &PG_VERSION_93 => 937,
         &PG_VERSION_94 => 942,
         &PG_VERSION_95 => 942,
@@ -298,6 +302,7 @@ sub dbControlVersion
         &PG_VERSION_13 => 1300,
         &PG_VERSION_14 => 1300,
         &PG_VERSION_15 => 1300,
+        &PG_VERSION_16 => 1300,
     };
 
     if (!defined($hControlVersion->{$strPgVersion}))
@@ -336,9 +341,6 @@ sub controlGenerateContent
     {
         32 =>
         {
-            '9.0' => 140 - length($tControlContent),
-            '9.1' => 140 - length($tControlContent),
-            '9.2' => 156 - length($tControlContent),
             '9.3' => 180 - length($tControlContent),
             '9.4' => 188 - length($tControlContent),
             '9.5' => 200 - length($tControlContent),
@@ -351,9 +353,6 @@ sub controlGenerateContent
 
         64 =>
         {
-            '9.0' => 152 - length($tControlContent),
-            '9.1' => 152 - length($tControlContent),
-            '9.2' => 168 - length($tControlContent),
             '9.3' => 192 - length($tControlContent),
             '9.4' => 200 - length($tControlContent),
             '9.5' => 216 - length($tControlContent),
@@ -442,9 +441,6 @@ sub walGenerateContent
     # Get WAL magic for the PG version
     my $hWalMagic =
     {
-        &PG_VERSION_90 => hex('0xD064'),
-        &PG_VERSION_91 => hex('0xD066'),
-        &PG_VERSION_92 => hex('0xD071'),
         &PG_VERSION_93 => hex('0xD075'),
         &PG_VERSION_94 => hex('0xD07E'),
         &PG_VERSION_95 => hex('0xD087'),
