@@ -152,10 +152,10 @@ sub backupLabel
     # Create backup label
     my $strBackupLabel = backupLabelFormat($strType, $strBackupLabelLast, $lTimestampStart);
 
-    # Make sure that the timestamp has not already been used by a prior backup.  This is unlikely for online backups since there is
+    # Make sure that the timestamp has not already been used by a prior backup. This is unlikely for online backups since there is
     # already a wait after the manifest is built but it's still possible if the remote and local systems don't have synchronized
-    # clocks.  In practice this is most useful for making offline testing faster since it allows the wait after manifest build to
-    # be skipped by dealing with any backup label collisions here.
+    # clocks. In practice this is most useful for making offline testing faster since it allows the wait after manifest build to be
+    # skipped by dealing with any backup label collisions here.
     if ($oStorageRepo->list(
         $strRepoBackupPath,
              {strExpression =>
@@ -229,11 +229,11 @@ sub run
 
         # Create hosts, file object, and config
         my ($oHostDbPrimary, $oHostDbStandby, $oHostBackup) = $self->setup(
-            true, $self->expect(),
+            true,
             {bHostBackup => $bRemote, bTls => $bTls, strStorage => $strStorage, bRepoEncrypt => $bEncrypt,
                 strCompressType => NONE});
 
-        # If S3 set process max to 2.  This seems like the best place for parallel testing since it will help speed S3 processing
+        # If S3 set process max to 2. This seems like the best place for parallel testing since it will help speed S3 processing
         # without slowing down the other tests too much.
         if ($strStorage eq S3)
         {
@@ -254,7 +254,7 @@ sub run
         $oManifest{&INI_SECTION_BACKREST}{&INI_KEY_VERSION} = PROJECT_VERSION;
         $oManifest{&INI_SECTION_BACKREST}{&INI_KEY_FORMAT} = REPOSITORY_FORMAT;
         $oManifest{&MANIFEST_SECTION_BACKUP_OPTION}{&MANIFEST_KEY_ARCHIVE_CHECK} = JSON::PP::false;
-        $oManifest{&MANIFEST_SECTION_BACKUP_OPTION}{&MANIFEST_KEY_ARCHIVE_COPY} = JSON::PP::true;
+        $oManifest{&MANIFEST_SECTION_BACKUP_OPTION}{&MANIFEST_KEY_ARCHIVE_COPY} = JSON::PP::false;
         $oManifest{&MANIFEST_SECTION_BACKUP_OPTION}{&MANIFEST_KEY_BACKUP_STANDBY} = JSON::PP::false;
         $oManifest{&MANIFEST_SECTION_BACKUP_OPTION}{&MANIFEST_KEY_BUFFER_SIZE} = 16384;
         $oManifest{&MANIFEST_SECTION_BACKUP_OPTION}{&MANIFEST_KEY_CHECKSUM_PAGE} = JSON::PP::true;
@@ -435,12 +435,12 @@ sub run
             $oHostDbPrimary->dbFileCreate(\%oManifest, MANIFEST_TARGET_PGDATA, 'base/32768/t333_44000', 'IGNORE');
         }
 
-        # Help and Version.  These have complete unit tests, so here just make sure there is output from the command line.
+        # Help and Version. These have complete unit tests, so here just make sure there is output from the command line.
         #---------------------------------------------------------------------------------------------------------------------------
         if ($self->runCurrent() == 1)
         {
-            $oHostDbPrimary->executeSimple($self->backrestExe() . " version", {oLogTest => $self->expect()});
-            $oHostDbPrimary->executeSimple($self->backrestExe() . " help version", {oLogTest => $self->expect()});
+            $oHostDbPrimary->executeSimple($self->backrestExe() . " version");
+            $oHostDbPrimary->executeSimple($self->backrestExe() . " help version");
         }
 
         # Full backup
@@ -784,7 +784,8 @@ sub run
             $oHostBackup->manifestMunge(
                 basename($strResumePath),
                 {&MANIFEST_SECTION_TARGET_FILE =>
-                    {(&MANIFEST_TARGET_PGDATA . '/badchecksum.txt') => {&MANIFEST_SUBKEY_CHECKSUM => BOGUS}}},
+                    {(&MANIFEST_TARGET_PGDATA . '/badchecksum.txt') =>
+                        {&MANIFEST_SUBKEY_CHECKSUM => 'aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa'}}},
                 false);
         }
         # Change contents of resumed file without changing size so it will throw a nasty error about the repo having been corrupted
@@ -850,12 +851,6 @@ sub run
 
         $oManifest{&MANIFEST_SECTION_BACKUP_OPTION}{&MANIFEST_KEY_PROCESS_MAX} = $strStorage eq S3 ? 2 : 1;
 
-        if (!$bRemote)
-        {
-            # Remove the size-changed test file to avoid expect log churn
-            $oHostDbPrimary->manifestFileRemove(\%oManifest, MANIFEST_TARGET_PGDATA, 'changesize.txt');
-        }
-
         # Drop tablespace 11
         #---------------------------------------------------------------------------------------------------------------------------
         $strType = CFGOPTVAL_BACKUP_TYPE_DIFF;
@@ -960,10 +955,12 @@ sub run
             $oHostBackup->configUpdate({&CFGDEF_SECTION_GLOBAL => {'compress-type' => $strCompressType}});
         }
 
-        # Enable hardlinks (except for s3) to ensure a warning is raised
+        # Enable hardlinks (except for s3) to show they can be enabled after a full backup
         if ($strStorage eq POSIX)
         {
             $oHostBackup->configUpdate({&CFGDEF_SECTION_GLOBAL => {'repo1-hardlink' => 'y'}});
+            $oManifest{&MANIFEST_SECTION_BACKUP_OPTION}{&MANIFEST_KEY_HARDLINK} = JSON::PP::true;
+            $oHostBackup->{bHardLink} = true;
         }
 
         $oManifest{&MANIFEST_SECTION_BACKUP_OPTION}{&MANIFEST_KEY_PROCESS_MAX} = 1;
@@ -987,16 +984,10 @@ sub run
         #---------------------------------------------------------------------------------------------------------------------------
         $strType = CFGOPTVAL_BACKUP_TYPE_FULL;
 
-        # Now the compression and hardlink changes will take effect
+        # Now the compression changes will take effect
         $oManifest{&MANIFEST_SECTION_BACKUP_OPTION}{&MANIFEST_KEY_COMPRESS} = JSON::PP::true;
         $oManifest{&MANIFEST_SECTION_BACKUP_OPTION}{&MANIFEST_KEY_COMPRESS_TYPE} = $strCompressType;
 
-        if ($strStorage eq POSIX)
-        {
-            $oManifest{&MANIFEST_SECTION_BACKUP_OPTION}{&MANIFEST_KEY_HARDLINK} = JSON::PP::true;
-            $oHostBackup->{bHardLink} = true;
-        }
-
         $oHostDbPrimary->manifestReference(\%oManifest);
 
         $oHostDbPrimary->manifestFileCreate(
@@ -1097,15 +1088,13 @@ sub run
         $oManifest{&MANIFEST_SECTION_BACKUP_TARGET}{'pg_tblspc/2'}{&MANIFEST_SUBKEY_PATH} = '../../tablespace/ts2';
         $oManifest{&MANIFEST_SECTION_TARGET_LINK}{'pg_data/pg_tblspc/2'}{&MANIFEST_SUBKEY_DESTINATION} = '../../tablespace/ts2';
 
-        # Dump out history path at the end to verify all history files are being recorded.  This test is only performed locally
+        # Dump out history path at the end to verify all history files are being recorded. This test is only performed locally
         # because for some reason sort order is different when this command is executed via ssh (even though the content of the
         # directory is identical).
         #---------------------------------------------------------------------------------------------------------------------------
         if (!$bRemote && $strStorage eq POSIX)
         {
-            executeTest(
-                'ls -1Rtr ' . $oHostBackup->repoBackupPath(PATH_BACKUP_HISTORY),
-                {oLogTest => $self->expect(), bRemote => $bRemote});
+            executeTest('ls -1Rtr ' . $oHostBackup->repoBackupPath(PATH_BACKUP_HISTORY), {bRemote => $bRemote});
         }
 
         # Test backup from standby warning that standby not configured so option reset
