@@ -72,7 +72,7 @@ testRun(void)
         Buffer *walBuffer = bufNew((size_t)16 * 1024 * 1024);
         bufUsedSet(walBuffer, bufSize(walBuffer));
         memset(bufPtr(walBuffer), 0, bufSize(walBuffer));
-        hrnPgWalToBuffer((PgWal){.version = PG_VERSION_10, .systemId = 0xFACEFACEFACEFACE}, walBuffer);
+        HRN_PG_WAL_TO_BUFFER(walBuffer, PG_VERSION_10);
 
         HRN_STORAGE_PUT(storagePgWrite(), "pg_wal/000000010000000100000002", walBuffer);
         HRN_STORAGE_PUT(storagePgWrite(), "pg_wal/000000010000000100000003", walBuffer);
@@ -104,9 +104,7 @@ testRun(void)
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("mismatched pg_control and archive.info - pg version");
 
-        HRN_STORAGE_PUT(
-            storageTest, "pg/" PG_PATH_GLOBAL "/" PG_FILE_PGCONTROL,
-            hrnPgControlToBuffer((PgControl){.version = PG_VERSION_96, .systemId = 0xFACEFACEFACEFACE}));
+        HRN_PG_CONTROL_PUT(storagePgWrite(), PG_VERSION_96);
 
         // Create incorrect archive info
         HRN_INFO_PUT(
@@ -120,9 +118,9 @@ testRun(void)
         TEST_ERROR(
             archivePushCheck(true), RepoInvalidError,
             "unable to find a valid repository:\n"
-            "repo1: [ArchiveMismatchError] PostgreSQL version 9.6, system-id 18072658121562454734 do not match repo1 stanza version"
-                " 9.4, system-id 5555555555555555555"
-                "\nHINT: are you archiving to the correct stanza?");
+            "repo1: [ArchiveMismatchError] PostgreSQL version 9.6, system-id " HRN_PG_SYSTEMID_96_Z " do not match repo1 stanza"
+            " version 9.4, system-id 5555555555555555555\n"
+            "HINT: are you archiving to the correct stanza?");
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("mismatched pg_control and archive.info - system-id");
@@ -139,9 +137,9 @@ testRun(void)
         TEST_ERROR(
             archivePushCheck(true), RepoInvalidError,
             "unable to find a valid repository:\n"
-            "repo1: [ArchiveMismatchError] PostgreSQL version 9.6, system-id 18072658121562454734 do not match repo1 stanza version"
-                " 9.6, system-id 5555555555555555555"
-                "\nHINT: are you archiving to the correct stanza?");
+            "repo1: [ArchiveMismatchError] PostgreSQL version 9.6, system-id " HRN_PG_SYSTEMID_96_Z " do not match repo1 stanza"
+            " version 9.6, system-id 5555555555555555555\n"
+            "HINT: are you archiving to the correct stanza?");
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("pg_control and archive.info match");
@@ -153,13 +151,13 @@ testRun(void)
             "db-id=1\n"
             "\n"
             "[db:history]\n"
-            "1={\"db-id\":18072658121562454734,\"db-version\":\"9.6\"}\n");
+            "1={\"db-id\":" HRN_PG_SYSTEMID_96_Z ",\"db-version\":\"9.6\"}\n");
 
         ArchivePushCheckResult result = {0};
         TEST_ASSIGN(result, archivePushCheck(true), "get archive check result");
 
         TEST_RESULT_UINT(result.pgVersion, PG_VERSION_96, "check pg version");
-        TEST_RESULT_UINT(result.pgSystemId, 0xFACEFACEFACEFACE, "check pg system id");
+        TEST_RESULT_UINT(result.pgSystemId, HRN_PG_SYSTEMID_96, "check pg system id");
 
         ArchivePushFileRepoData *repoData = lstGet(result.repoList, 0);
         TEST_RESULT_UINT(repoData->repoIdx, 0, "check repo idx");
@@ -183,7 +181,7 @@ testRun(void)
             "db-id=1\n"
             "\n"
             "[db:history]\n"
-            "1={\"db-id\":18072658121562454734,\"db-version\":\"9.6\"}\n");
+            "1={\"db-id\":" HRN_PG_SYSTEMID_96_Z ",\"db-version\":\"9.6\"}\n");
 
         // repo4 has incorrect info
         HRN_INFO_PUT(
@@ -197,11 +195,11 @@ testRun(void)
         TEST_ASSIGN(result, archivePushCheck(false), "get archive check result");
 
         TEST_RESULT_UINT(result.pgVersion, PG_VERSION_96, "check pg version");
-        TEST_RESULT_UINT(result.pgSystemId, 0xFACEFACEFACEFACE, "check pg system id");
+        TEST_RESULT_UINT(result.pgSystemId, HRN_PG_SYSTEMID_96, "check pg system id");
         TEST_RESULT_STRLST_Z(
             result.errorList,
-            "repo4: [ArchiveMismatchError] repo2 stanza version 9.6, system-id 18072658121562454734 do not match repo4 stanza"
-                " version 9.4, system-id 5555555555555555555\n"
+            "repo4: [ArchiveMismatchError] repo2 stanza version 9.6, system-id " HRN_PG_SYSTEMID_96_Z " do not match repo4 stanza"
+            " version 9.4, system-id 5555555555555555555\n"
             "HINT: are you archiving to the correct stanza?\n",
             "check error list");
 
@@ -222,12 +220,12 @@ testRun(void)
             "\n"
             "[db:history]\n"
             "1={\"db-id\":5555555555555555555,\"db-version\":\"9.4\"}\n"
-            "2={\"db-id\":18072658121562454734,\"db-version\":\"9.6\"}\n");
+            "2={\"db-id\":" HRN_PG_SYSTEMID_96_Z ",\"db-version\":\"9.6\"}\n");
 
         TEST_ASSIGN(result, archivePushCheck(false), "get archive check result");
 
         TEST_RESULT_UINT(result.pgVersion, PG_VERSION_96, "check pg version");
-        TEST_RESULT_UINT(result.pgSystemId, 0xFACEFACEFACEFACE, "check pg system id");
+        TEST_RESULT_UINT(result.pgSystemId, HRN_PG_SYSTEMID_96, "check pg system id");
 
         repoData = lstGet(result.repoList, 0);
         TEST_RESULT_UINT(repoData->repoIdx, 0, "check repo idx");
@@ -289,9 +287,7 @@ testRun(void)
         strLstAddZ(argListTemp, "pg_wal/000000010000000100000001");
         HRN_CFG_LOAD(cfgCmdArchivePush, argListTemp);
 
-        HRN_STORAGE_PUT(
-            storageTest, "pg/" PG_PATH_GLOBAL "/" PG_FILE_PGCONTROL,
-            hrnPgControlToBuffer((PgControl){.version = PG_VERSION_11, .systemId = 0xFACEFACEFACEFACE}));
+        HRN_PG_CONTROL_PUT(storagePgWrite(), PG_VERSION_11);
 
         HRN_INFO_PUT(
             storageRepoIdxWrite(0), INFO_ARCHIVE_PATH_FILE,
@@ -299,13 +295,13 @@ testRun(void)
             "db-id=1\n"
             "\n"
             "[db:history]\n"
-            "1={\"db-id\":18072658121562454734,\"db-version\":\"11\"}\n");
+            "1={\"db-id\":" HRN_PG_SYSTEMID_11_Z ",\"db-version\":\"11\"}\n");
 
         // Generate WAL with incorrect headers and try to push them
         Buffer *walBuffer1 = bufNew((size_t)16 * 1024 * 1024);
         bufUsedSet(walBuffer1, bufSize(walBuffer1));
         memset(bufPtr(walBuffer1), 0, bufSize(walBuffer1));
-        hrnPgWalToBuffer((PgWal){.version = PG_VERSION_10, .systemId = 0xFACEFACEFACEFACE}, walBuffer1);
+        HRN_PG_WAL_TO_BUFFER(walBuffer1, PG_VERSION_10);
 
         HRN_STORAGE_PUT(storagePgWrite(), "pg_wal/000000010000000100000001", walBuffer1);
 
@@ -313,19 +309,19 @@ testRun(void)
 
         TEST_ERROR(
             cmdArchivePush(), ArchiveMismatchError,
-            "WAL file '" TEST_PATH "/pg/pg_wal/000000010000000100000001' version 10, system-id 18072658121562454734 do not match"
-                " stanza version 11, system-id 18072658121562454734");
+            "WAL file '" TEST_PATH "/pg/pg_wal/000000010000000100000001' version 10, system-id " HRN_PG_SYSTEMID_10_Z " do not"
+            " match stanza version 11, system-id " HRN_PG_SYSTEMID_11_Z "");
 
         memset(bufPtr(walBuffer1), 0, bufSize(walBuffer1));
-        hrnPgWalToBuffer((PgWal){.version = PG_VERSION_11, .systemId = 0xECAFECAFECAFECAF}, walBuffer1);
-        const char *walBuffer1Sha1 = strZ(bufHex(cryptoHashOne(HASH_TYPE_SHA1_STR, walBuffer1)));
+        HRN_PG_WAL_TO_BUFFER(walBuffer1, PG_VERSION_11, .systemId = 1);
+        const char *walBuffer1Sha1 = strZ(strNewEncode(encodingHex, cryptoHashOne(hashTypeSha1, walBuffer1)));
 
         HRN_STORAGE_PUT(storagePgWrite(), "pg_wal/000000010000000100000001", walBuffer1);
 
         TEST_ERROR(
             cmdArchivePush(), ArchiveMismatchError,
-            "WAL file '" TEST_PATH "/pg/pg_wal/000000010000000100000001' version 11, system-id 17055110554209741999 do not match"
-                " stanza version 11, system-id 18072658121562454734");
+            "WAL file '" TEST_PATH "/pg/pg_wal/000000010000000100000001' version 11, system-id " HRN_PG_SYSTEMID_11_1_Z " do not"
+            " match stanza version 11, system-id " HRN_PG_SYSTEMID_11_Z);
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("push by ignoring the invalid header");
@@ -339,46 +335,47 @@ testRun(void)
         TEST_RESULT_LOG("P00   INFO: pushed WAL file '000000010000000100000001' to the archive");
 
         TEST_STORAGE_EXISTS(
-            storageRepoIdxWrite(0), strZ(strNewFmt(STORAGE_REPO_ARCHIVE "/11-1/000000010000000100000001-%s.gz", walBuffer1Sha1)),
+            storageRepoIdxWrite(0), zNewFmt(STORAGE_REPO_ARCHIVE "/11-1/000000010000000100000001-%s.gz", walBuffer1Sha1),
             .remove = true, .comment = "check repo for WAL file, then remove");
 
         // -------------------------------------------------------------------------------------------------------------------------
-        TEST_TITLE("generate valid WAL and push them");
+        TEST_TITLE("generate valid WAL and push them, with parameter --no-archive-mode-check to suppress duplicate WAL warning");
 
         argListTemp = strLstDup(argList);
+        hrnCfgArgRawNegate(argListTemp, cfgOptArchiveModeCheck);
         strLstAddZ(argListTemp, "pg_wal/000000010000000100000001");
         HRN_CFG_LOAD(cfgCmdArchivePush, argListTemp);
 
         memset(bufPtr(walBuffer1), 0, bufSize(walBuffer1));
-        hrnPgWalToBuffer((PgWal){.version = PG_VERSION_11, .systemId = 0xFACEFACEFACEFACE}, walBuffer1);
-
-        // Check sha1 checksum against fixed values once to make sure they are not getting munged. After this we'll calculate them
-        // directly from the buffers to reduce the cost of maintaining checksums.
-        walBuffer1Sha1 = TEST_64BIT() ?
-            (TEST_BIG_ENDIAN() ? "1c5f963d720bb199d7935dbd315447ea2ec3feb2" : "aae7591a1dbc58f21d0d004886075094f622e6dd") :
-            "28a13fd8cf6fcd9f9a8108aed4c8bcc58040863a";
+        HRN_PG_WAL_TO_BUFFER(walBuffer1, PG_VERSION_11);
 
         HRN_STORAGE_PUT(storagePgWrite(), "pg_wal/000000010000000100000001", walBuffer1);
 
         TEST_RESULT_VOID(cmdArchivePush(), "push the WAL segment");
         TEST_RESULT_LOG("P00   INFO: pushed WAL file '000000010000000100000001' to the archive");
 
-        TEST_STORAGE_EXISTS(
-            storageRepoIdxWrite(0), strZ(strNewFmt(STORAGE_REPO_ARCHIVE "/11-1/000000010000000100000001-%s.gz", walBuffer1Sha1)),
+        // Check sha1 checksum against fixed values once to make sure they are not getting munged. After this we'll calculate them
+        // directly from the buffers to reduce the cost of maintaining checksums.
+        TEST_STORAGE_LIST(
+            storageRepoIdx(0), STORAGE_REPO_ARCHIVE "/11-1/0000000100000001",
+            zNewFmt(
+                "000000010000000100000001-%s.gz\n",
+                TEST_64BIT() ?
+                    (TEST_BIG_ENDIAN() ? "4dc9df63290935f68f43b7d02005716a98800ce0" : "858a9ef24b79468eb2a61543b58140addfede0fc") :
+                    "044ec0576dc4e59d460aa3a8ac796ba4874ddff3"),
             .comment = "check repo for WAL file");
 
+        // No warning emitted re WAL file already existing with the same checksum due to --no-archive-mode-check
         TEST_RESULT_VOID(cmdArchivePush(), "push the WAL segment again");
         TEST_RESULT_LOG(
-            "P00   WARN: WAL file '000000010000000100000001' already exists in the repo1 archive with the same checksum\n"
-            "            HINT: this is valid in some recovery scenarios but may also indicate a problem.\n"
             "P00   INFO: pushed WAL file '000000010000000100000001' to the archive");
 
         // Now create a new WAL buffer with a different checksum to test checksum errors
         Buffer *walBuffer2 = bufNew((size_t)16 * 1024 * 1024);
         bufUsedSet(walBuffer2, bufSize(walBuffer2));
         memset(bufPtr(walBuffer2), 0xFF, bufSize(walBuffer2));
-        hrnPgWalToBuffer((PgWal){.version = PG_VERSION_11, .systemId = 0xFACEFACEFACEFACE}, walBuffer2);
-        const char *walBuffer2Sha1 = strZ(bufHex(cryptoHashOne(HASH_TYPE_SHA1_STR, walBuffer2)));
+        HRN_PG_WAL_TO_BUFFER(walBuffer2, PG_VERSION_11);
+        const char *walBuffer2Sha1 = strZ(strNewEncode(encodingHex, cryptoHashOne(hashTypeSha1, walBuffer2)));
 
         HRN_STORAGE_PUT(storagePgWrite(), "pg_wal/000000010000000100000001", walBuffer2);
 
@@ -400,8 +397,7 @@ testRun(void)
         // Create tmp file to make it look like a prior push failed partway through to ensure that retries work
         HRN_STORAGE_PUT_Z(
             storageTest,
-            strZ(
-                strNewFmt("repo/archive/test/11-1/0000000100000001/000000010000000100000002-%s.gz.pgbackrest.tmp", walBuffer2Sha1)),
+            zNewFmt("repo/archive/test/11-1/0000000100000001/000000010000000100000002-%s.gz.pgbackrest.tmp", walBuffer2Sha1),
             "PARTIAL", .comment = "write WAL tmp file");
 
         TEST_RESULT_VOID(cmdArchivePush(), "push the WAL segment");
@@ -409,9 +405,7 @@ testRun(void)
 
         TEST_STORAGE_EXISTS(
             storageRepoIdxWrite(0),
-            strZ(
-                strNewFmt(
-                    STORAGE_REPO_ARCHIVE "/11-1/0000000100000001/000000010000000100000002-%s.gz", walBuffer2Sha1)),
+            zNewFmt(STORAGE_REPO_ARCHIVE "/11-1/0000000100000001/000000010000000100000002-%s.gz", walBuffer2Sha1),
             .comment = "check repo for WAL file");
         TEST_RESULT_BOOL(
             storageExistsP(
@@ -459,12 +453,55 @@ testRun(void)
             "            HINT: this is valid in some recovery scenarios but may also indicate a problem.\n"
             "P00   INFO: pushed WAL file '000000010000000100000002' to the archive");
 
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("push WAL with modified control/catalog/magic using the --pg-version option");
+
+        argListTemp = strLstDup(argList);
+        strLstAddZ(argListTemp, "pg_wal/000000010000000100000003");
+        HRN_CFG_LOAD(cfgCmdArchivePush, argListTemp);
+
+        memset(bufPtr(walBuffer1), 0, bufSize(walBuffer1));
+        HRN_PG_WAL_OVERRIDE_TO_BUFFER(walBuffer1, PG_VERSION_11, 999);
+        HRN_STORAGE_PUT(storagePgWrite(), "pg_wal/000000010000000100000003", walBuffer1);
+
+        TEST_ERROR(
+            cmdArchivePush(), VersionNotSupportedError,
+            "unexpected WAL magic 999\n"
+            "HINT: is this version of PostgreSQL supported?");
+
+        HRN_PG_CONTROL_OVERRIDE_PUT(storagePgWrite(), PG_VERSION_11, 1501, .catalogVersion = 202211111);
+
+        TEST_ERROR(
+            cmdArchivePush(), VersionNotSupportedError,
+            "unexpected control version = 1501 and catalog version = 202211111\n"
+            "HINT: is this version of PostgreSQL supported?");
+
+        argListTemp = strLstDup(argList);
+        hrnCfgArgRawZ(argListTemp, cfgOptPgVersionForce, "11");
+        strLstAddZ(argListTemp, "pg_wal/000000010000000100000003");
+        HRN_CFG_LOAD(cfgCmdArchivePush, argListTemp);
+
+        TEST_RESULT_VOID(cmdArchivePush(), "push the WAL segment with a modified control/catalog version");
+        TEST_RESULT_LOG(
+            "P00   INFO: pushed WAL file '000000010000000100000003' to the archive");
+
+        // Reset control file
+        HRN_PG_CONTROL_PUT(storagePgWrite(), PG_VERSION_11);
+
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("multiple repos, one encrypted");
 
         // Remove old repo
         HRN_STORAGE_PATH_REMOVE(storageTest, "repo", .errorOnMissing = true, .recurse = true);
 
+        // Create an artificially small WAL file to save time on encryption
+        walBuffer2 = bufNew(1024);
+        bufUsedSet(walBuffer2, bufSize(walBuffer2));
+        memset(bufPtr(walBuffer2), 0xFF, bufSize(walBuffer2));
+        HRN_PG_WAL_TO_BUFFER(walBuffer2, PG_VERSION_11);
+        walBuffer2Sha1 = strZ(strNewEncode(encodingHex, cryptoHashOne(hashTypeSha1, walBuffer2)));
+        HRN_STORAGE_PUT(storageTest, "pg/pg_wal/000000010000000100000002", walBuffer2, .comment = "write WAL");
+
         argListTemp = strLstNew();
         hrnCfgArgRawZ(argListTemp, cfgOptStanza, "test");
         hrnCfgArgKeyRawZ(argListTemp, cfgOptPgPath, 1, TEST_PATH "/pg");
@@ -487,7 +524,7 @@ testRun(void)
             "db-id=1\n"
             "\n"
             "[db:history]\n"
-            "1={\"db-id\":18072658121562454734,\"db-version\":\"11\"}",
+            "1={\"db-id\":" HRN_PG_SYSTEMID_11_Z ",\"db-version\":\"11\"}",
             .cipherType = cipherTypeAes256Cbc, .cipherPass = "badpassphrase");
 
         // repo3 is not encrypted
@@ -497,18 +534,18 @@ testRun(void)
             "db-id=1\n"
             "\n"
             "[db:history]\n"
-            "1={\"db-id\":18072658121562454734,\"db-version\":\"11\"}");
+            "1={\"db-id\":" HRN_PG_SYSTEMID_11_Z ",\"db-version\":\"11\"}");
 
         // Push encrypted WAL segment
         TEST_RESULT_VOID(cmdArchivePush(), "push the WAL segment");
         TEST_RESULT_LOG("P00   INFO: pushed WAL file '000000010000000100000002' to the archive");
 
         TEST_STORAGE_EXISTS(
-            storageTest, strZ(strNewFmt("repo2/archive/test/11-1/0000000100000001/000000010000000100000002-%s", walBuffer2Sha1)),
+            storageTest, zNewFmt("repo2/archive/test/11-1/0000000100000001/000000010000000100000002-%s", walBuffer2Sha1),
             .remove = true, .comment = "check repo2 for WAL file then remove");
 
         TEST_STORAGE_EXISTS(
-            storageTest, strZ(strNewFmt("repo3/archive/test/11-1/0000000100000001/000000010000000100000002-%s", walBuffer2Sha1)),
+            storageTest, zNewFmt("repo3/archive/test/11-1/0000000100000001/000000010000000100000002-%s", walBuffer2Sha1),
             .remove = true, .comment = "check repo3 for WAL file then remove");
 
         // -------------------------------------------------------------------------------------------------------------------------
@@ -516,18 +553,17 @@ testRun(void)
 
         HRN_STORAGE_MODE(storageTest, "repo2/archive/test/11-1/0000000100000001", .mode = 0500);
 
-        TEST_ERROR(
+        TEST_ERROR_FMT(
             cmdArchivePush(), CommandError,
-            strZ(
-                strNewFmt(
-                    "archive-push command encountered error(s):\n"
-                    "repo2: [FileOpenError] unable to open file '" TEST_PATH "/repo2/archive/test/11-1/0000000100000001"
-                        "/000000010000000100000002-%s' for write: [13] Permission denied", walBuffer2Sha1)));
+            "archive-push command encountered error(s):\n"
+            "repo2: [FileOpenError] unable to open file '" TEST_PATH "/repo2/archive/test/11-1/0000000100000001"
+            "/000000010000000100000002-%s' for write: [13] Permission denied",
+            walBuffer2Sha1);
 
         TEST_STORAGE_LIST_EMPTY(storageTest, "repo2/archive/test/11-1/0000000100000001", .comment = "check repo2 for no WAL file");
         TEST_STORAGE_LIST(
-            storageTest, "repo3/archive/test/11-1/0000000100000001",
-            strZ(strNewFmt("000000010000000100000002-%s\n", walBuffer2Sha1)), .comment = "check repo3 for WAL file");
+            storageTest, "repo3/archive/test/11-1/0000000100000001", zNewFmt("000000010000000100000002-%s\n", walBuffer2Sha1),
+            .comment = "check repo3 for WAL file");
 
         HRN_STORAGE_MODE(storageTest, "repo2/archive/test/11-1/0000000100000001");
 
@@ -541,8 +577,8 @@ testRun(void)
             "P00   INFO: pushed WAL file '000000010000000100000002' to the archive");
 
         TEST_STORAGE_LIST(
-            storageTest, "repo2/archive/test/11-1/0000000100000001",
-            strZ(strNewFmt("000000010000000100000002-%s\n", walBuffer2Sha1)), .comment = "check repo2 for WAL file");
+            storageTest, "repo2/archive/test/11-1/0000000100000001", zNewFmt("000000010000000100000002-%s\n", walBuffer2Sha1),
+            .comment = "check repo2 for WAL file");
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("WAL already exists in both repos");
@@ -559,10 +595,10 @@ testRun(void)
         TEST_TITLE("push succeeds on one repo when other repo fails to load archive.info");
 
         TEST_STORAGE_EXISTS(
-            storageTest, strZ(strNewFmt("repo2/archive/test/11-1/0000000100000001/000000010000000100000002-%s", walBuffer2Sha1)),
+            storageTest, zNewFmt("repo2/archive/test/11-1/0000000100000001/000000010000000100000002-%s", walBuffer2Sha1),
             .remove = true);
         TEST_STORAGE_EXISTS(
-            storageTest, strZ(strNewFmt("repo3/archive/test/11-1/0000000100000001/000000010000000100000002-%s", walBuffer2Sha1)),
+            storageTest, zNewFmt("repo3/archive/test/11-1/0000000100000001/000000010000000100000002-%s", walBuffer2Sha1),
             .remove = true);
         HRN_STORAGE_MODE(storageTest, "repo2", .mode = 0200);
 
@@ -570,10 +606,10 @@ testRun(void)
             cmdArchivePush(), CommandError,
             "archive-push command encountered error(s):\n"
             "repo2: [FileOpenError] unable to load info file '" TEST_PATH "/repo2/archive/test/archive.info' or"
-                " '" TEST_PATH "/repo2/archive/test/archive.info.copy':\n"
+            " '" TEST_PATH "/repo2/archive/test/archive.info.copy':\n"
             "FileOpenError: unable to open file '" TEST_PATH "/repo2/archive/test/archive.info' for read: [13] Permission denied\n"
             "FileOpenError: unable to open file '" TEST_PATH "/repo2/archive/test/archive.info.copy' for read:"
-                " [13] Permission denied\n"
+            " [13] Permission denied\n"
             "HINT: archive.info cannot be opened but is required to push/get WAL segments.\n"
             "HINT: is archive_command configured correctly in postgresql.conf?\n"
             "HINT: has a stanza-create been performed?\n"
@@ -581,7 +617,7 @@ testRun(void)
 
         // Make sure WAL got pushed to repo3
         TEST_STORAGE_EXISTS(
-            storageTest, strZ(strNewFmt("repo3/archive/test/11-1/0000000100000001/000000010000000100000002-%s", walBuffer2Sha1)),
+            storageTest, zNewFmt("repo3/archive/test/11-1/0000000100000001/000000010000000100000002-%s", walBuffer2Sha1),
             .remove = true);
 
         HRN_STORAGE_MODE(storageTest, "repo2");
@@ -595,11 +631,11 @@ testRun(void)
             cmdArchivePush(), CommandError,
             "archive-push command encountered error(s):\n"
             "repo2: [PathOpenError] unable to list file info for path '" TEST_PATH "/repo2/archive/test/11-1/0000000100000001':"
-                " [13] Permission denied");
+            " [13] Permission denied");
 
         // Make sure WAL got pushed to repo3
         TEST_STORAGE_EXISTS(
-            storageTest, strZ(strNewFmt("repo3/archive/test/11-1/0000000100000001/000000010000000100000002-%s", walBuffer2Sha1)),
+            storageTest, zNewFmt("repo3/archive/test/11-1/0000000100000001/000000010000000100000002-%s", walBuffer2Sha1),
             .remove = true);
 
         HRN_STORAGE_MODE(storageTest, "repo2/archive/test/11-1");
@@ -612,7 +648,7 @@ testRun(void)
 
         // Install local command handler shim
         static const ProtocolServerHandler testLocalHandlerList[] = {PROTOCOL_SERVER_HANDLER_ARCHIVE_PUSH_LIST};
-        hrnProtocolLocalShimInstall(testLocalHandlerList, PROTOCOL_SERVER_HANDLER_LIST_SIZE(testLocalHandlerList));
+        hrnProtocolLocalShimInstall(testLocalHandlerList, LENGTH_OF(testLocalHandlerList));
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("command must be run on the pg host");
@@ -658,7 +694,8 @@ testRun(void)
 
         TEST_ERROR(
             cmdArchivePush(), ArchiveTimeoutError,
-            "unable to push WAL file 'bogus' to the archive asynchronously after 1 second(s)");
+            "unable to push WAL file 'bogus' to the archive asynchronously after 1 second(s)\n"
+            "HINT: check '" HRN_PATH "/test-archive-push-async.log' for errors.");
 
         // Create pg_control and archive.info for next set of tests
         // -------------------------------------------------------------------------------------------------------------------------
@@ -671,8 +708,7 @@ testRun(void)
         hrnCfgArgRawZ(argList, cfgOptRepoPath, TEST_PATH "/repo");
         hrnCfgArgRawBool(argList, cfgOptLogSubprocess, true);
 
-        HRN_STORAGE_PUT(storageTest, "pg/" PG_PATH_GLOBAL "/" PG_FILE_PGCONTROL,
-            hrnPgControlToBuffer((PgControl){.version = PG_VERSION_94, .systemId = 0xAAAABBBBCCCCDDDD}));
+        HRN_PG_CONTROL_PUT(storagePgWrite(), PG_VERSION_94);
 
         HRN_INFO_PUT(
             storageTest, "repo/archive/test/archive.info",
@@ -680,7 +716,7 @@ testRun(void)
             "db-id=1\n"
             "\n"
             "[db:history]\n"
-            "1={\"db-id\":12297848147757817309,\"db-version\":\"9.4\"}\n");
+            "1={\"db-id\":" HRN_PG_SYSTEMID_94_Z ",\"db-version\":\"9.4\"}\n");
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("async, ignore error file on first pass");
@@ -713,8 +749,8 @@ testRun(void)
         {
             HRN_FORK_CHILD_BEGIN()
             {
-                lockAcquire(
-                    cfgOptionStr(cfgOptLockPath), cfgOptionStr(cfgOptStanza), STRDEF("555-fefefefe"), cfgLockType(), 30000, true);
+                lockInit(cfgOptionStr(cfgOptLockPath), STRDEF("555-fefefefe"), cfgOptionStr(cfgOptStanza), cfgLockType());
+                lockAcquireP(.timeout = 30000, .returnOnNoLock = true);
 
                 // Notify parent that lock has been acquired
                 HRN_FORK_CHILD_NOTIFY_PUT();
@@ -733,7 +769,8 @@ testRun(void)
 
                 TEST_ERROR(
                     cmdArchivePush(), ArchiveTimeoutError,
-                    "unable to push WAL file '000000010000000100000001' to the archive asynchronously after 1 second(s)");
+                    "unable to push WAL file '000000010000000100000001' to the archive asynchronously after 1 second(s)\n"
+                    "HINT: check '" HRN_PATH "/test-archive-push-async.log' for errors.");
 
                 // Notify child to release lock
                 HRN_FORK_PARENT_NOTIFY_PUT(0);
@@ -755,8 +792,8 @@ testRun(void)
         Buffer *walBuffer1 = bufNew((size_t)16 * 1024 * 1024);
         bufUsedSet(walBuffer1, bufSize(walBuffer1));
         memset(bufPtr(walBuffer1), 0xFF, bufSize(walBuffer1));
-        hrnPgWalToBuffer((PgWal){.version = PG_VERSION_94, .systemId = 0xAAAABBBBCCCCDDDD}, walBuffer1);
-        const char *walBuffer1Sha1 = strZ(bufHex(cryptoHashOne(HASH_TYPE_SHA1_STR, walBuffer1)));
+        HRN_PG_WAL_TO_BUFFER(walBuffer1, PG_VERSION_94);
+        const char *walBuffer1Sha1 = strZ(strNewEncode(encodingHex, cryptoHashOne(hashTypeSha1, walBuffer1)));
 
         HRN_STORAGE_PUT(storagePgWrite(),"pg_xlog/000000010000000100000001", walBuffer1);
 
@@ -764,7 +801,7 @@ testRun(void)
         TEST_RESULT_LOG("P00   INFO: pushed WAL file '000000010000000100000001' to the archive asynchronously");
 
         TEST_STORAGE_EXISTS(
-            storageTest, strZ(strNewFmt("repo/archive/test/9.4-1/0000000100000001/000000010000000100000001-%s", walBuffer1Sha1)),
+            storageTest, zNewFmt("repo/archive/test/9.4-1/0000000100000001/000000010000000100000001-%s", walBuffer1Sha1),
             .comment = "check repo for WAL file");
 
         // -------------------------------------------------------------------------------------------------------------------------
@@ -816,13 +853,13 @@ testRun(void)
             "db-id=1\n"
             "\n"
             "[db:history]\n"
-            "1={\"db-id\":12297848147757817309,\"db-version\":\"9.4\"}\n");
+            "1={\"db-id\":" HRN_PG_SYSTEMID_94_Z ",\"db-version\":\"9.4\"}\n");
 
         // Recreate ready file for WAL 1
         HRN_STORAGE_PUT_EMPTY(storagePgWrite(), "pg_xlog/archive_status/000000010000000100000001.ready");
 
         TEST_STORAGE_EXISTS(
-            storageTest, strZ(strNewFmt("repo/archive/test/9.4-1/0000000100000001/000000010000000100000001-%s", walBuffer1Sha1)),
+            storageTest, zNewFmt("repo/archive/test/9.4-1/0000000100000001/000000010000000100000001-%s", walBuffer1Sha1),
             .comment = "check repo1 for WAL 1 file");
 
         // Create a ready file for WAL 2 but don't create the segment yet -- this will test the file error
@@ -835,16 +872,16 @@ testRun(void)
             "            HINT: this is valid in some recovery scenarios but may also indicate a problem.\n"
             "P01 DETAIL: pushed WAL file '000000010000000100000001' to the archive\n"
             "P01   WARN: could not push WAL file '000000010000000100000002' to the archive (will be retried): "
-                "[55] raised from local-1 shim protocol: " STORAGE_ERROR_READ_MISSING "\n"
-            "            [FileMissingError] on retry after 0ms",
+            "[55] raised from local-1 shim protocol: " STORAGE_ERROR_READ_MISSING "\n"
+            "            [RETRY DETAIL OMITTED]",
             TEST_PATH "/pg/pg_xlog/000000010000000100000002");
 
         TEST_STORAGE_EXISTS(
-            storageTest, strZ(strNewFmt("repo/archive/test/9.4-1/0000000100000001/000000010000000100000001-%s", walBuffer1Sha1)),
+            storageTest, zNewFmt("repo/archive/test/9.4-1/0000000100000001/000000010000000100000001-%s", walBuffer1Sha1),
             .comment = "check repo1 for WAL 1 file");
 
         TEST_STORAGE_EXISTS(
-            storageTest, strZ(strNewFmt("repo3/archive/test/9.4-1/0000000100000001/000000010000000100000001-%s", walBuffer1Sha1)),
+            storageTest, zNewFmt("repo3/archive/test/9.4-1/0000000100000001/000000010000000100000001-%s", walBuffer1Sha1),
             .comment = "check repo3 for WAL 1 file");
 
         TEST_STORAGE_LIST(
@@ -860,8 +897,8 @@ testRun(void)
         Buffer *walBuffer2 = bufNew((size_t)16 * 1024 * 1024);
         bufUsedSet(walBuffer2, bufSize(walBuffer2));
         memset(bufPtr(walBuffer2), 0x0C, bufSize(walBuffer2));
-        hrnPgWalToBuffer((PgWal){.version = PG_VERSION_94, .systemId = 0xAAAABBBBCCCCDDDD}, walBuffer2);
-        const char *walBuffer2Sha1 = strZ(bufHex(cryptoHashOne(HASH_TYPE_SHA1_STR, walBuffer2)));
+        HRN_PG_WAL_TO_BUFFER(walBuffer2, PG_VERSION_94);
+        const char *walBuffer2Sha1 = strZ(strNewEncode(encodingHex, cryptoHashOne(hashTypeSha1, walBuffer2)));
 
         HRN_STORAGE_PUT(storagePgWrite(), "pg_xlog/000000010000000100000002", walBuffer2);
 
@@ -875,10 +912,10 @@ testRun(void)
             "P01 DETAIL: pushed WAL file '000000010000000100000002' to the archive");
 
         TEST_STORAGE_EXISTS(
-            storageTest, strZ(strNewFmt("repo/archive/test/9.4-1/0000000100000001/000000010000000100000002-%s", walBuffer2Sha1)),
+            storageTest, zNewFmt("repo/archive/test/9.4-1/0000000100000001/000000010000000100000002-%s", walBuffer2Sha1),
             .comment = "check repo1 for WAL 2 file");
         TEST_STORAGE_EXISTS(
-            storageTest, strZ(strNewFmt("repo3/archive/test/9.4-1/0000000100000001/000000010000000100000002-%s", walBuffer2Sha1)),
+            storageTest, zNewFmt("repo3/archive/test/9.4-1/0000000100000001/000000010000000100000002-%s", walBuffer2Sha1),
             .comment = "check repo3 for WAL 2 file");
 
         TEST_STORAGE_LIST(
@@ -909,8 +946,8 @@ testRun(void)
         Buffer *walBuffer3 = bufNew((size_t)16 * 1024 * 1024);
         bufUsedSet(walBuffer3, bufSize(walBuffer3));
         memset(bufPtr(walBuffer3), 0x44, bufSize(walBuffer3));
-        hrnPgWalToBuffer((PgWal){.version = PG_VERSION_94, .systemId = 0xAAAABBBBCCCCDDDD}, walBuffer3);
-        const char *walBuffer3Sha1 = strZ(bufHex(cryptoHashOne(HASH_TYPE_SHA1_STR, walBuffer3)));
+        HRN_PG_WAL_TO_BUFFER(walBuffer3, PG_VERSION_94);
+        const char *walBuffer3Sha1 = strZ(strNewEncode(encodingHex, cryptoHashOne(hashTypeSha1, walBuffer3)));
 
         HRN_STORAGE_PUT(storagePgWrite(), "pg_xlog/000000010000000100000003", walBuffer3);
 
@@ -923,10 +960,10 @@ testRun(void)
             "P01 DETAIL: pushed WAL file '000000010000000100000003' to the archive");
 
         TEST_STORAGE_EXISTS(
-            storageTest, strZ(strNewFmt("repo/archive/test/9.4-1/0000000100000001/000000010000000100000003-%s", walBuffer3Sha1)),
+            storageTest, zNewFmt("repo/archive/test/9.4-1/0000000100000001/000000010000000100000003-%s", walBuffer3Sha1),
             .comment = "check repo1 for WAL 3 file");
         TEST_STORAGE_EXISTS(
-            storageTest, strZ(strNewFmt("repo3/archive/test/9.4-1/0000000100000001/000000010000000100000003-%s", walBuffer3Sha1)),
+            storageTest, zNewFmt("repo3/archive/test/9.4-1/0000000100000001/000000010000000100000003-%s", walBuffer3Sha1),
             .comment = "check repo3 for WAL 3 file");
 
         // Remove the ready file to prevent WAL 3 from being considered for the next test
