@@ -15,7 +15,7 @@ Test functions for IoRead that are not covered by testing the IoBufferRead objec
 static bool
 testIoReadOpen(void *driver)
 {
-    if (driver == (void *)998)
+    if (strEqZ(driver, "998"))
         return false;
 
     return true;
@@ -24,7 +24,7 @@ testIoReadOpen(void *driver)
 static size_t
 testIoRead(void *driver, Buffer *buffer, bool block)
 {
-    ASSERT(driver == (void *)999);
+    ASSERT(strEqZ(driver, "999"));
     (void)block;
 
     bufCat(buffer, BUFSTRDEF("Z"));
@@ -37,7 +37,7 @@ static bool testIoReadCloseCalled = false;
 static void
 testIoReadClose(void *driver)
 {
-    ASSERT(driver == (void *)999);
+    ASSERT(strEqZ(driver, "999"));
     testIoReadCloseCalled = true;
 }
 
@@ -49,15 +49,15 @@ static bool testIoWriteOpenCalled = false;
 static void
 testIoWriteOpen(void *driver)
 {
-    ASSERT(driver == (void *)999);
+    ASSERT(strEqZ(driver, "999"));
     testIoWriteOpenCalled = true;
 }
 
 static void
-testIoWrite(void *driver, const Buffer *buffer)
+testIoWrite(void *const driver, const Buffer *const buffer)
 {
-    ASSERT(driver == (void *)999);
-    ASSERT(strEq(strNewBuf(buffer), STRDEF("ABC")));
+    ASSERT(strEqZ(driver, "999"));
+    ASSERT(strncmp((const char *)bufPtrConst(buffer), "ABC", bufSize(buffer)) == 0);
 }
 
 static bool testIoWriteCloseCalled = false;
@@ -65,7 +65,7 @@ static bool testIoWriteCloseCalled = false;
 static void
 testIoWriteClose(void *driver)
 {
-    ASSERT(driver == (void *)999);
+    ASSERT(strEqZ(driver, "999"));
     testIoWriteCloseCalled = true;
 }
 
@@ -106,28 +106,27 @@ ioTestFilterSizeResult(THIS_VOID)
     pckWriteU64P(packWrite, this->size);
     pckWriteEndP(packWrite);
 
-    return pckWriteResult(packWrite);
+    Pack *const result = pckDup(pckWriteResult(packWrite));
+
+    pckWriteFree(packWrite);
+
+    return result;
 }
 
 static IoFilter *
 ioTestFilterSizeNew(const StringId type)
 {
-    IoFilter *this = NULL;
-
-    OBJ_NEW_BEGIN(IoTestFilterSize)
+    OBJ_NEW_BEGIN(IoTestFilterSize, .childQty = MEM_CONTEXT_QTY_MAX)
     {
-        IoTestFilterSize *driver = OBJ_NEW_ALLOC();
-        *driver = (IoTestFilterSize){0};
-
-        this = ioFilterNewP(type, driver, NULL, .in = ioTestFilterSizeProcess, .result = ioTestFilterSizeResult);
+        *this = (IoTestFilterSize){0};
     }
     OBJ_NEW_END();
 
-    return this;
+    return ioFilterNewP(type, this, NULL, .in = ioTestFilterSizeProcess, .result = ioTestFilterSizeResult);
 }
 
 /***********************************************************************************************************************************
-Test filter to multiply input to the output.  It can also flush out a variable number of bytes at the end.
+Test filter to multiply input to the output. It can also flush out a variable number of bytes at the end.
 ***********************************************************************************************************************************/
 typedef struct IoTestFilterMultiply
 {
@@ -140,7 +139,7 @@ typedef struct IoTestFilterMultiply
 } IoTestFilterMultiply;
 
 static void
-ioTestFilterMultiplyProcess(THIS_VOID, const Buffer *input, Buffer *output)
+ioTestFilterMultiplyProcess(THIS_VOID, const Buffer *const input, Buffer *const output)
 {
     THIS(IoTestFilterMultiply);
 
@@ -163,7 +162,7 @@ ioTestFilterMultiplyProcess(THIS_VOID, const Buffer *input, Buffer *output)
         else
         {
             char flushZ[] = {this->flushChar, 0};
-            bufCat(output, bufNewC(flushZ, 1));
+            bufCat(output, BUF(flushZ, 1));
             this->flushTotal--;
         }
     }
@@ -171,7 +170,12 @@ ioTestFilterMultiplyProcess(THIS_VOID, const Buffer *input, Buffer *output)
     {
         if (this->multiplyBuffer == NULL)
         {
-            this->multiplyBuffer = bufNew(bufUsed(input) * this->multiplier);
+            MEM_CONTEXT_OBJ_BEGIN(this)
+            {
+                this->multiplyBuffer = bufNew(bufUsed(input) * this->multiplier);
+            }
+            MEM_CONTEXT_OBJ_END();
+
             const unsigned char *inputPtr = bufPtrConst(input);
             unsigned char *bufferPtr = bufPtr(this->multiplyBuffer);
 
@@ -212,33 +216,27 @@ ioTestFilterMultiplyInputSame(const THIS_VOID)
 static IoFilter *
 ioTestFilterMultiplyNew(const StringId type, unsigned int multiplier, unsigned int flushTotal, char flushChar)
 {
-    IoFilter *this = NULL;
-
-    OBJ_NEW_BEGIN(IoTestFilterMultiply)
+    OBJ_NEW_BEGIN(IoTestFilterMultiply, .childQty = MEM_CONTEXT_QTY_MAX)
     {
-        IoTestFilterMultiply *driver = OBJ_NEW_ALLOC();
-
-        *driver = (IoTestFilterMultiply)
+        *this = (IoTestFilterMultiply)
         {
             .bufferFilter = ioBufferNew(),
             .multiplier = multiplier,
             .flushTotal = flushTotal,
             .flushChar = flushChar,
         };
-
-        PackWrite *const packWrite = pckWriteNewP();
-        pckWriteStrIdP(packWrite, type);
-        pckWriteU32P(packWrite, multiplier);
-        pckWriteU32P(packWrite, flushTotal);
-        pckWriteEndP(packWrite);
-
-        this = ioFilterNewP(
-            type, driver, pckWriteResult(packWrite), .done = ioTestFilterMultiplyDone, .inOut = ioTestFilterMultiplyProcess,
-            .inputSame = ioTestFilterMultiplyInputSame);
     }
     OBJ_NEW_END();
 
-    return this;
+    PackWrite *const packWrite = pckWriteNewP();
+    pckWriteStrIdP(packWrite, type);
+    pckWriteU32P(packWrite, multiplier);
+    pckWriteU32P(packWrite, flushTotal);
+    pckWriteEndP(packWrite);
+
+    return ioFilterNewP(
+        type, this, pckWriteResult(packWrite), .done = ioTestFilterMultiplyDone, .inOut = ioTestFilterMultiplyProcess,
+        .inputSame = ioTestFilterMultiplyInputSame);
 }
 
 /***********************************************************************************************************************************
@@ -269,13 +267,13 @@ testRun(void)
         ioBufferSizeSet(2);
 
         TEST_ASSIGN(
-            read, ioReadNewP((void *)998, .close = testIoReadClose, .open = testIoReadOpen, .read = testIoRead),
+            read, ioReadNewP(strNewZ("998"), .close = testIoReadClose, .open = testIoReadOpen, .read = testIoRead),
             "create io read object");
 
         TEST_RESULT_BOOL(ioReadOpen(read), false, "    open io object");
 
         TEST_ASSIGN(
-            read, ioReadNewP((void *)999, .close = testIoReadClose, .open = testIoReadOpen, .read = testIoRead),
+            read, ioReadNewP(strNewZ("999"), .close = testIoReadClose, .open = testIoReadOpen, .read = testIoRead),
             "create io read object");
 
         TEST_RESULT_BOOL(ioReadOpen(read), true, "    open io object");
@@ -395,7 +393,7 @@ testRun(void)
         filterGroup->pub.closed = true;
         TEST_RESULT_UINT(pckReadU64P(ioFilterGroupResultP(filterGroup, STRID5("test", 0xa4cb40))), 777, "    check filter result");
 
-        // Read a zero-size buffer to ensure filters are still processed even when there is no input.  Some filters (e.g. encryption
+        // Read a zero-size buffer to ensure filters are still processed even when there is no input. Some filters (e.g. encryption
         // and compression) will produce output even if there is no input.
         // -------------------------------------------------------------------------------------------------------------------------
         ioBufferSizeSet(1024);
@@ -466,7 +464,7 @@ testRun(void)
         TEST_RESULT_STR_Z(ioReadLineParam(read, true), "1234", "read line without eof");
 
         // -------------------------------------------------------------------------------------------------------------------------
-        TEST_TITLE("ioCopy()");
+        TEST_TITLE("ioCopyP()");
 
         ioBufferSizeSet(4);
 
@@ -475,11 +473,26 @@ testRun(void)
         buffer = bufNew(0);
         IoWrite *bufferWrite = ioBufferWriteNewOpen(buffer);
 
-        TEST_RESULT_VOID(ioCopy(bufferRead, bufferWrite), "copy buffer");
+        TEST_RESULT_VOID(ioCopyP(bufferRead, bufferWrite), "copy buffer");
         TEST_RESULT_VOID(ioWriteClose(bufferWrite), "close write");
 
         TEST_RESULT_STR_Z(strNewBuf(buffer), "a test string", "check buffer");
 
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("ioCopyP() with limit");
+
+        ioBufferSizeSet(4);
+
+        bufferRead = ioBufferReadNewOpen(BUFSTRDEF("a test string"));
+
+        buffer = bufNew(0);
+        bufferWrite = ioBufferWriteNewOpen(buffer);
+
+        TEST_RESULT_VOID(ioCopyP(bufferRead, bufferWrite, .limit = VARUINT64(6)), "copy buffer");
+        TEST_RESULT_VOID(ioWriteClose(bufferWrite), "close write");
+
+        TEST_RESULT_STR_Z(strNewBuf(buffer), "a test", "check buffer");
+
         // Read IO into a buffer
         // -------------------------------------------------------------------------------------------------------------------------
         ioBufferSizeSet(8);
@@ -499,7 +512,7 @@ testRun(void)
 
         // Cannot open file
         TEST_ASSIGN(
-            read, ioReadNewP((void *)998, .close = testIoReadClose, .open = testIoReadOpen, .read = testIoRead),
+            read, ioReadNewP(strNewZ("998"), .close = testIoReadClose, .open = testIoReadOpen, .read = testIoRead),
             "create io read object");
         TEST_RESULT_BOOL(ioReadDrain(read), false, "cannot open");
     }
@@ -511,7 +524,7 @@ testRun(void)
         ioBufferSizeSet(3);
 
         TEST_ASSIGN(
-            write, ioWriteNewP((void *)999, .close = testIoWriteClose, .open = testIoWriteOpen, .write = testIoWrite),
+            write, ioWriteNewP(strNewZ("999"), .close = testIoWriteClose, .open = testIoWriteOpen, .write = testIoWrite),
             "create io write object");
 
         TEST_RESULT_VOID(ioWriteOpen(write), "    open io object");
@@ -563,6 +576,46 @@ testRun(void)
             pckReadU64P(ioFilterGroupResultP(filterGroup, STRID5("size2", 0x1c2e9330))), 22, "    check filter result");
     }
 
+    // *****************************************************************************************************************************
+    if (testBegin("ioReadVarIntU64() and ioWriteVarIntU64()"))
+    {
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("ioWriteVarIntU64()");
+
+        Buffer *buffer = bufNew(32);
+        IoWrite *write = ioBufferWriteNewOpen(buffer);
+
+        TEST_RESULT_VOID(ioWriteVarIntU64(write, 7777777), "write varint");
+        TEST_RESULT_VOID(ioWriteVarIntU64(write, 0), "write varint");
+        TEST_RESULT_VOID(ioWriteClose(write), "close write");
+
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("ioReadVarIntU64()");
+
+        IoRead *read = ioBufferReadNewOpen(buffer);
+
+        TEST_RESULT_UINT(ioReadVarIntU64(read), 7777777, "read varint");
+        TEST_RESULT_UINT(ioReadVarIntU64(read), 0, "read varint");
+
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("error on eof");
+
+        bufPtr(buffer)[0] = 0xFF;
+        bufUsedSet(buffer, 1);
+        read = ioBufferReadNewOpen(buffer);
+
+        TEST_ERROR(ioReadVarIntU64(read), FileReadError, "unexpected eof");
+
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("error on too many bytes");
+
+        memset(bufPtr(buffer), 0xFF, bufSize(buffer));
+        bufUsedSet(buffer, bufSize(buffer));
+        read = ioBufferReadNewOpen(buffer);
+
+        TEST_ERROR(ioReadVarIntU64(read), FormatError, "unterminated base-128 integer");
+    }
+
     // *****************************************************************************************************************************
     if (testBegin("IoFdRead, IoFdWrite, and ioFdWriteOneStr()"))
     {
@@ -707,5 +760,29 @@ testRun(void)
         TRY_END();
     }
 
+    // *****************************************************************************************************************************
+    if (testBegin("IoLimitRead"))
+    {
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("read limit");
+
+        const Buffer *input = BUFSTRZ("ABCDEF");
+        ioBufferSizeSet(2);
+        IoRead *read = ioLimitReadNew(ioBufferReadNewOpen(input), 5);
+        ioReadOpen(read);
+
+        Buffer *output = bufNew(2);
+        TEST_RESULT_UINT(ioRead(read, output), 2, "read");
+        TEST_RESULT_STR_Z(strNewBuf(output), "AB", "check");
+
+        bufUsedZero(output);
+        TEST_RESULT_UINT(ioRead(read, output), 2, "read");
+        TEST_RESULT_STR_Z(strNewBuf(output), "CD", "check");
+
+        bufUsedZero(output);
+        TEST_RESULT_UINT(ioRead(read, output), 1, "read");
+        TEST_RESULT_STR_Z(strNewBuf(output), "E", "check");
+    }
+
     FUNCTION_HARNESS_RETURN_VOID();
 }
